@@ -57,8 +57,7 @@ bool QvkDownloader::saveLocal( const QString &filename, QIODevice *data )
 {
     QString fileInTempPath = tempPath + "/" + filename;
     QFile file( fileInTempPath );
-    if ( !file.open( QIODevice::WriteOnly ) )
-    {
+    if ( !file.open( QIODevice::WriteOnly ) ) {
         return false;
     }
     file.write( data->readAll() );
@@ -70,14 +69,10 @@ bool QvkDownloader::saveLocal( const QString &filename, QIODevice *data )
 void QvkDownloader::slot_downloadFinished( QNetworkReply *reply )
 {
     QString filename = QFileInfo( reply->url().path() ).fileName();
-    if ( reply->error() )
-    {
+    if ( reply->error() ) {
         //qDebug().noquote() << global::nameOutput << "Download of" << reply->url().toString() << "failed:" << reply->errorString();
-    }
-    else
-    {
-        if ( saveLocal( filename, reply ) )
-        {
+    } else {
+        if ( saveLocal( filename, reply ) ) {
             //qDebug().noquote() << global::nameOutput << "Download of" << reply->url().toString() << "succeeded (saved to" << tempPath + "/" + filename + ")";
         }
     }
@@ -85,8 +80,7 @@ void QvkDownloader::slot_downloadFinished( QNetworkReply *reply )
     listDownloads.removeAll( reply );
     reply->deleteLater();
 
-    if ( listDownloads.isEmpty() )
-    {
+    if ( listDownloads.isEmpty() ) {
         // all downloads finished
         emit signal_fileDownloaded( tempPath + "/" + filename );
     }
