@@ -13,6 +13,13 @@
         <translation>Càmera</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSettingsDialog</name>
+    <message>
+        <source>Camera settings</source>
+        <translation>Ajustaments de la càmera</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraSingle</name>
     <message>
@@ -78,6 +85,13 @@
         <translation>Divertiu-vos amb el vokoscreenNG</translation>
     </message>
 </context>
+<context>
+    <name>QvkDirDialog</name>
+    <message>
+        <source>Dialog</source>
+        <translation>Diàleg</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -132,14 +146,6 @@
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Pantalla completa</translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>Finestra</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
         <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
@@ -166,6 +172,25 @@
         <translation>Feu una donació</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>Codi font</translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>Lloc web</translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>Traduccions</translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>Feu una donació</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
@@ -356,10 +381,6 @@
         <source>Audiocodec</source>
         <translation>Còdec de l&apos;àudio</translation>
     </message>
-    <message>
-        <source>Quality</source>
-        <translation>Qualitat</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>No enregistris el cursor del ratolí</translation>
@@ -512,10 +533,6 @@
         <source>Remove window frame</source>
         <translation>Elimina el marc de la finestra</translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>Feu una donació</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>Restableix tots els ajustaments en el proper inici</translation>
@@ -592,6 +609,113 @@
         <source>Seconds wait before recording</source>
         <translation>Segons d&apos;espera abans de l&apos;enregistrament</translation>
     </message>
+    <message>
+        <source>Window</source>
+        <translation>Finestra</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Pantalla completa</translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>Drets d&apos;autor i llicència de les imatges</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Crea imatges de les pestanyes</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Informació de la llicència</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>ACTIU</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>INACTIU</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>Temps enregistrat:</translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>Mida del vídeo:</translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>Espai lliure al disc:</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>Informació</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>Finestra</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Pantalla completa</translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>Àrea</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>Còdec del vídeo</translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>Fotogrames</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Format</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>Disponible</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>No disponible</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>Inicia</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>Atura</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>Pausa</translation>
+    </message>
+    <message>
+        <source>Continue</source>
+        <translation>Continua</translation>
+    </message>
+    <message>
+        <source>Play</source>
+        <translation>Reprodueix</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Carpeta</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>No enregistris el cursor del ratolí</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -601,7 +725,7 @@
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>Reprodueix</translation>
@@ -614,29 +738,5 @@
         <source>Stop</source>
         <translation>Atura</translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation>Obre un fitxer</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Pantalla completa</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>Fotograma anterior</translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>Fotograma següent</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>Silenci</translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>Mou el menú</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
