@@ -13,6 +13,13 @@
         <translation>Kamera</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSettingsDialog</name>
+    <message>
+        <source>Camera settings</source>
+        <translation>Nastavení kamery</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraSingle</name>
     <message>
@@ -78,6 +85,13 @@
         <translation>Hezkou zábavu s vokoscreenNG</translation>
     </message>
 </context>
+<context>
+    <name>QvkDirDialog</name>
+    <message>
+        <source>Dialog</source>
+        <translation>Dialog</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -132,14 +146,6 @@
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Celá obrazovka</translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>Okno</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
         <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
@@ -166,6 +172,25 @@
         <translation>Podpořit</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>Zdrojový kód</translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>Domovská stránka</translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>Překlad</translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>Podpořit</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
@@ -356,10 +381,6 @@
         <source>Audiocodec</source>
         <translation>Audiokodek</translation>
     </message>
-    <message>
-        <source>Quality</source>
-        <translation>Kvalita</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>Nenahrávat kurzor myši</translation>
@@ -512,10 +533,6 @@
         <source>Remove window frame</source>
         <translation>Odstranit rám okna</translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>Podpořit</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>Obnovit všechna nastavení při následujícím spuštění</translation>
@@ -595,6 +612,113 @@ Vteřin počkat před nahráváním??
 Sekund počkej před natáčením??
 Sekund počkej před záznamem??</translation>
     </message>
+    <message>
+        <source>Window</source>
+        <translation>Okno</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Celá obrazovka</translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>Autorská práva a licence k obrázkům</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Vytvořit snímky karet</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Informace o licenci</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>Zapnuto</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>Vypnuto</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>Doba záznamu:</translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>Velikost videa:</translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>Volné místo na disku:</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>Informace</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>Okno</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Celá obrazovka</translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>Výřez</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>Videokodek</translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>Snímky</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Formát</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>Dostupný</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>Nedostupný</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>Start</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>Stop</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>Pauza</translation>
+    </message>
+    <message>
+        <source>Continue</source>
+        <translation>Pokračovat</translation>
+    </message>
+    <message>
+        <source>Play</source>
+        <translation>Přehrát</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Adresář</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>Nenahrávat kurzor myši</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -604,7 +728,7 @@ Sekund počkej před záznamem??</translation>
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>Přehrát</translation>
@@ -617,29 +741,5 @@ Sekund počkej před záznamem??</translation>
         <source>Stop</source>
         <translation>Stop</translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation>Otevřít soubor</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Celá obrazovka</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>Předchozí snímek</translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>Následující snímek</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>Ztlumit</translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>Přesunout nabídku</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
