@@ -13,6 +13,13 @@
         <translation>Kamera</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSettingsDialog</name>
+    <message>
+        <source>Camera settings</source>
+        <translation>Kameraeinstellungen</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraSingle</name>
     <message>
@@ -78,6 +85,13 @@
         <translation>Have fun with vokoscreenNG</translation>
     </message>
 </context>
+<context>
+    <name>QvkDirDialog</name>
+    <message>
+        <source>Dialog</source>
+        <translation>Dialog</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -132,14 +146,6 @@
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Vollbild</translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>Fenster</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
         <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
@@ -166,6 +172,25 @@
         <translation>Spenden</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>Quellcode</translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>Webseite</translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>Übersetzungen</translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>Spenden</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
@@ -356,10 +381,6 @@
         <source>Audiocodec</source>
         <translation>Audiocodec</translation>
     </message>
-    <message>
-        <source>Quality</source>
-        <translation>Qualität</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>Mauszeiger nicht aufnehmen</translation>
@@ -512,10 +533,6 @@
         <source>Remove window frame</source>
         <translation>Fensterrahmen entfernen</translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>Spenden</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>Alle Einstellungen beim nächsten Start zurücksetzen</translation>
@@ -592,6 +609,113 @@
         <source>Seconds wait before recording</source>
         <translation>Sekunden warten, bevor die Aufnahme beginnt.</translation>
     </message>
+    <message>
+        <source>Window</source>
+        <translation>Fenster</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Vollbild</translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>Copyright und Lizenz von Bildern</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Erstelle Bilder von Tabs</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Lizenz Information</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>Ein</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>Aus</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>Aufnahmezeit:</translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>Videogröße:</translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>Freier Plattenplatz:</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>Information</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>Fenster</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Vollbild</translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>Bereich</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>Videocodec</translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>Bilder</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Format</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>Verfügbar</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>Nicht verfügbar</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>Start</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>Stop</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>Pause</translation>
+    </message>
+    <message>
+        <source>Continue</source>
+        <translation>Weiter</translation>
+    </message>
+    <message>
+        <source>Play</source>
+        <translation>Play</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Ordner</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>Mauszeiger nicht aufnehmen</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -601,7 +725,7 @@
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>Play</translation>
@@ -614,29 +738,5 @@
         <source>Stop</source>
         <translation>Stop</translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation>Datei öffnen</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Vollbild</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>Vorheriges Bild</translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>Nächstes Bild</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>Stummschaltung</translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>Menü verschieben</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
