@@ -13,6 +13,13 @@
         <translation>Κάμερα</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSettingsDialog</name>
+    <message>
+        <source>Camera settings</source>
+        <translation>Ρυθμίσεις Κάμερας</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraSingle</name>
     <message>
@@ -78,6 +85,13 @@
         <translation>Διασκεδάστε με το vokoscreenNG</translation>
     </message>
 </context>
+<context>
+    <name>QvkDirDialog</name>
+    <message>
+        <source>Dialog</source>
+        <translation>Διάλογος</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -132,14 +146,6 @@
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Πλήρης οθόνη</translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>Παράθυρο</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
         <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
@@ -166,6 +172,25 @@
         <translation>Δωρεά</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>Πηγαίος κώδικας</translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>Αρχική</translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>Μεταφράσεις</translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>Δωρεά</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
@@ -356,10 +381,6 @@
         <source>Audiocodec</source>
         <translation>Κωδικοποιητής ήχου</translation>
     </message>
-    <message>
-        <source>Quality</source>
-        <translation>Ποιότητα</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>Μην καταγράφεις τον κέρσορα</translation>
@@ -512,10 +533,6 @@
         <source>Remove window frame</source>
         <translation>Αφαίρεσε το πλαίσιο παραθύρου</translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>Δωρεά</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>Επαναφορά όλων των ρυθμίσεων στην επόμενη εκκίνηση</translation>
@@ -592,6 +609,113 @@
         <source>Seconds wait before recording</source>
         <translation>Δευτερόλεπτα αναμονής πριν την έναρξη της εγγραφής</translation>
     </message>
+    <message>
+        <source>Window</source>
+        <translation>Παράθυρο</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Πλήρης οθόνη</translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>Πνευματικά δικαιώματα και άδεια από τις φωτογραφίες</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Δημιουργία εικόνων των καρτελών</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Πληροφορίες για την άδεια χρήσης</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>ΟΝ</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>ΟFF</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>Χρόνος Εγγραφής:</translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>Μέγεθος βίντεο:</translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>Ελεύθερος χώρος στο δίσκο:</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>Πληροφορίες</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>Παράθυρο</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Πλήρης οθόνη</translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>Περιοχή</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>Κωδικοποιητής βίντεο</translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>Στιγμιότυπα</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Τύπος αρχείου</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>Διαθέσιμο</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>Μη διαθέσιμο</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>Έναρξη</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>Διακοπή</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>Παύση</translation>
+    </message>
+    <message>
+        <source>Continue</source>
+        <translation>Συνέχιση</translation>
+    </message>
+    <message>
+        <source>Play</source>
+        <translation>Αναπαραγωγή</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Φάκελος</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>Μην καταγράφεις τον κέρσορα</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -601,7 +725,7 @@
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>Αναπαραγωγή</translation>
@@ -614,29 +738,5 @@
         <source>Stop</source>
         <translation>Διακοπή</translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation>Άνοιγμα αρχείου</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Πλήρης οθόνη</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>Προηγούμενο στιγμιότυπο</translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>Επόμενο στιγμιότυπο</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>Σίγαση</translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>Μετακίνησε το μενού</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
