@@ -13,6 +13,13 @@
         <translation>Camera</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSettingsDialog</name>
+    <message>
+        <source>Camera settings</source>
+        <translation>Camera settings</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraSingle</name>
     <message>
@@ -78,6 +85,13 @@
         <translation>Have fun with vokoscreenNG</translation>
     </message>
 </context>
+<context>
+    <name>QvkDirDialog</name>
+    <message>
+        <source>Dialog</source>
+        <translation>Dialogue</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -132,14 +146,6 @@
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Fullscreen</translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>Window</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
         <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
@@ -166,6 +172,25 @@
         <translation>Donate</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>Sourcecode</translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>Homepage</translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>Translations</translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>Donate</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
@@ -356,10 +381,6 @@
         <source>Audiocodec</source>
         <translation>Audiocodec</translation>
     </message>
-    <message>
-        <source>Quality</source>
-        <translation>Quality</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>Do not record mouse cursor</translation>
@@ -512,10 +533,6 @@
         <source>Remove window frame</source>
         <translation>Remove window frame</translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>Donate</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>Reset all settings at the next start</translation>
@@ -592,6 +609,113 @@
         <source>Seconds wait before recording</source>
         <translation>Seconds wait before recording</translation>
     </message>
+    <message>
+        <source>Window</source>
+        <translation>Window</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Fullscreen</translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>Copyright and license from pictures</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Create images of tabs </translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>License information</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>ON</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>OFF</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>Record Time:</translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>Video size:</translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>Free disk space:</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>Information</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>Window</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Fullscreen</translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>Area</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>Videocodec</translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>Frames</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Format</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>Available</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>Not available</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>Start</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>Stop</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>Pause</translation>
+    </message>
+    <message>
+        <source>Continue</source>
+        <translation>Continue</translation>
+    </message>
+    <message>
+        <source>Play</source>
+        <translation>Play</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Folder</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>Do not record mouse cursor</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -601,7 +725,7 @@
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>Play</translation>
@@ -614,29 +738,5 @@
         <source>Stop</source>
         <translation>Stop</translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation>Open File</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Fullscreen</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>Previous frame</translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>Next frame</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>Mute</translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>Move menu</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
