@@ -13,6 +13,13 @@
         <translation>Cámara</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSettingsDialog</name>
+    <message>
+        <source>Camera settings</source>
+        <translation>Configuración de la cámara</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraSingle</name>
     <message>
@@ -78,6 +85,13 @@
         <translation>Diviértete con vokoscreenNG</translation>
     </message>
 </context>
+<context>
+    <name>QvkDirDialog</name>
+    <message>
+        <source>Dialog</source>
+        <translation>Diálogo</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -132,14 +146,6 @@
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Pantalla Completa</translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>Ventana</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
         <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
@@ -166,6 +172,25 @@
         <translation>Donar</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>Código fuente</translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>Página de inicio</translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>Traducciones</translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>Donar</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
@@ -356,10 +381,6 @@
         <source>Audiocodec</source>
         <translation>Codec de audio</translation>
     </message>
-    <message>
-        <source>Quality</source>
-        <translation>Calidad</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>No grabar el cursor del ratón</translation>
@@ -512,10 +533,6 @@
         <source>Remove window frame</source>
         <translation>Remover el marco de la ventana</translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>Donar</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>Redefinir la configuración en la siguiente grabación</translation>
@@ -592,6 +609,113 @@
         <source>Seconds wait before recording</source>
         <translation>Segundos de espera antes de grabar</translation>
     </message>
+    <message>
+        <source>Window</source>
+        <translation>Ventana</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Pantalla Completa</translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>Derechos de autor y licencia sobre la grabación</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Crear imágenes de tabuladores</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Información de Licencia</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>Inicio</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>Apagado</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>Tiempo de grabación:</translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>Tamaño del video:</translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>Espacio libre del disco:</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>Información</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>Ventana</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Pantalla Completa</translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>Área</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>Codec de video</translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>Cuadros</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Formato</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>Disponible</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>No disponible</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>Comenzar</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>Detener</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>Pausar</translation>
+    </message>
+    <message>
+        <source>Continue</source>
+        <translation>Continuar</translation>
+    </message>
+    <message>
+        <source>Play</source>
+        <translation>Reproducir</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Carpeta</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>No grabar el cursor del ratón</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -601,7 +725,7 @@
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>Reproducir</translation>
@@ -614,29 +738,5 @@
         <source>Stop</source>
         <translation>Detener</translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation>Abrir Archivo</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Pantalla Completa</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>Cuadro anterior</translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>Siguiente cuadro</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>Apagar el micrófono</translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>Mover el menú</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
