@@ -14,7 +14,38 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraWindow</name>
+    <name>QvkCameraSettingsDialog</name>
+    <message>
+        <source>Camera settings</source>
+        <translation>تنظیمات دوربین</translation>
+    </message>
+</context>
+<context>
+    <name>QvkCameraSingle</name>
+    <message>
+        <source>Remove window frame</source>
+        <translation>حذف فریم دور پنچره</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>عمودی چرخاندن</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>افقی چرخاندن</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>معکوس کردن</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>خاکستری</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>سیاه و سفید</translation>
+    </message>
     <message>
         <source>Switch to Window</source>
         <translation>تغییر به حالت پنجره</translation>
@@ -24,19 +55,41 @@
         <translation>تغییر به حالت تمام صفحه</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraWindow</name>
+    <message>
+        <source>Switch to Window</source>
+        <translation>تغییر به حالت پنجره</translation>
+    </message>
+    <message>
+        <source>Switch to Fullscreen</source>
+        <translation>تغییر به حالت تمام صفحه</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>دوربین</translation>
+    </message>
+</context>
 <context>
     <name>QvkCiscoFinishDialog</name>
     <message>
         <source>The setup was successful.</source>
-        <translation type="unfinished"/>
+        <translation>تنظیمات موفقیت آمیز بود</translation>
     </message>
     <message>
         <source>Close this window and start vokoscreenNG again.</source>
-        <translation type="unfinished"/>
+        <translation>بستن پنجره و شروع دوباره برنامه</translation>
     </message>
     <message>
         <source>Have fun with vokoscreenNG</source>
-        <translation type="unfinished"/>
+        <translation>از وکواسکرین لذت ببرید</translation>
+    </message>
+</context>
+<context>
+    <name>QvkDirDialog</name>
+    <message>
+        <source>Dialog</source>
+        <translation>گفتگو</translation>
     </message>
 </context>
 <context>
@@ -95,16 +148,9 @@
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation>تمام صفحه</translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>پنجره</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
+        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
         <translation>برنامه مدیریت فایل پیدا نشد.</translation>
     </message>
     <message>
@@ -128,6 +174,25 @@
         <translation>حمایت</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>کد منبع</translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>صفحه اصلی</translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>ترجمه ها</translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>حمایت</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
@@ -149,6 +214,17 @@
         <translation>محیط</translation>
     </message>
 </context>
+<context>
+    <name>QvkSnapshot</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>برنامه مدیریت فایل پیدا نشد.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>لطفا برنامه یک برنامه مدیریت فایل نصب کنید.</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -211,6 +287,13 @@
         <translation>بزرگنمایی</translation>
     </message>
 </context>
+<context>
+    <name>QvkWASAPIController</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>انتخاب یک یا چند دستگاه </translation>
+    </message>
+</context>
 <context>
     <name>cameraSettingsDialog</name>
     <message>
@@ -300,10 +383,6 @@
         <source>Audiocodec</source>
         <translation>کدک صدا</translation>
     </message>
-    <message>
-        <source>Quality</source>
-        <translation>کیفیت</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>نشانگر موس را ضبط نکن</translation>
@@ -408,10 +487,6 @@
         <source>Gray</source>
         <translation>سیاه و سفید</translation>
     </message>
-    <message>
-        <source>Send Report</source>
-        <translation>ارسال گزارش</translation>
-    </message>
     <message>
         <source>CTRL+SHIFT+F10</source>
         <translation>CTRL+SHIFT+F10</translation>
@@ -460,10 +535,6 @@
         <source>Remove window frame</source>
         <translation>حذف فریم دور پنچره</translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>حمایت</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>بازنشانی همه تنظیمات در شروع بعدی</translation>
@@ -490,39 +561,162 @@
     </message>
     <message>
         <source>Automatically</source>
-        <translation type="unfinished"/>
+        <translation>خودکار</translation>
     </message>
     <message>
         <source>Create images of tabs </source>
-        <translation type="unfinished"/>
+        <translation>ایجاد تصاویر برای هر تب</translation>
     </message>
     <message>
         <source>License information</source>
-        <translation type="unfinished"/>
+        <translation>اطلاعات لایسنس</translation>
     </message>
     <message>
         <source>ON</source>
-        <translation type="unfinished"/>
+        <translation>روشن</translation>
     </message>
     <message>
         <source>OFF</source>
-        <translation type="unfinished"/>
+        <translation>خاموش</translation>
     </message>
     <message>
         <source>Global keyboard shortcuts</source>
-        <translation type="unfinished"/>
+        <translation>میانبرهای فراگیر صفحه کلید</translation>
     </message>
     <message>
         <source>Assigned shortcut keys.</source>
-        <translation type="unfinished"/>
+        <translation>کلیدهای میانبر تعریف شده </translation>
     </message>
     <message>
         <source>Keyboard shortcut not assigned or assigned more than once.</source>
-        <translation type="unfinished"/>
+        <translation>میانبر صفحه کلید تعریف نشده یا بیش از یکبار تعریف شده</translation>
     </message>
     <message>
         <source>If it shows assigned but does not work, it is being used by another program.</source>
-        <translation type="unfinished"/>
+        <translation>اگر تعریف شده نشان داده شده اما کار نمیکند،توسط برنامه دیگری استفاده شده</translation>
+    </message>
+    <message>
+        <source>Snapshot</source>
+        <translation>عکس گرفتن فوری</translation>
+    </message>
+    <message>
+        <source>Imagepath</source>
+        <translation>مسیر تصویر</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>مخفی سازی پنجره</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>تعداد ثانیه‌هایی که باید قبل از شروع ضبط منتظر بمانید </translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>پنجره</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>تمام صفحه</translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>کپی رایت و مجوز برای عکس ها</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>ایجاد تصاویر برای هر تب</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>اطلاعات لایسنس</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>روشن</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>خاموش</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>زمان ضبط:</translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>اندازه ویدیو:</translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>فضای آزاد حافظه:</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>اطلاعات</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>پنجره</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>تمام صفحه</translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>محیط</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>کدک ویدیو</translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>فریم‌ها</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>فرمت</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>دردسترس است</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>دردسترس نیست</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>شروع</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>پایان</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>وقفه</translation>
+    </message>
+    <message>
+        <source>Continue</source>
+        <translation>ادامه</translation>
+    </message>
+    <message>
+        <source>Play</source>
+        <translation>پخش</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>پوشه</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>نشانگر موس را ضبط نکن</translation>
     </message>
 </context>
 <context>
@@ -533,7 +727,7 @@
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>پخش</translation>
@@ -544,31 +738,7 @@
     </message>
     <message>
         <source>Stop</source>
-        <translation>توقف</translation>
-    </message>
-    <message>
-        <source>Open File</source>
-        <translation>باز کردن فایل</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>تمام صفحه</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>فریم قبلی</translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>فریم بعدی</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>بی‌صدا</translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>جابه‌جایی منو</translation>
+        <translation>پایان</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
