@@ -13,6 +13,13 @@
         <translation>Kamera</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSettingsDialog</name>
+    <message>
+        <source>Camera settings</source>
+        <translation>Kameran asetukset</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraSingle</name>
     <message>
@@ -78,6 +85,13 @@
         <translation>Pidä hauskaa vokoscreenNG:n parissa</translation>
     </message>
 </context>
+<context>
+    <name>QvkDirDialog</name>
+    <message>
+        <source>Dialog</source>
+        <translation>Valintaikkuna</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -132,14 +146,6 @@
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Koko näyttö</translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>Ikkuna</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
         <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
@@ -166,6 +172,25 @@
         <translation>Lahjoita</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>Lähdekoodi</translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>Kotisivu</translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>Käännökset</translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>Lahjoita</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
@@ -356,10 +381,6 @@
         <source>Audiocodec</source>
         <translation>Audiokoodekki</translation>
     </message>
-    <message>
-        <source>Quality</source>
-        <translation>Laatu</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>Älä tallenna hiiren osoitinta</translation>
@@ -512,10 +533,6 @@
         <source>Remove window frame</source>
         <translation>Poista ikkunakehys</translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>Lahjoita</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>Nollaa kaikki asetukset seuraavalla käynnistyksellä</translation>
@@ -592,6 +609,113 @@
         <source>Seconds wait before recording</source>
         <translation>Odotusaika ennen tallennusta</translation>
     </message>
+    <message>
+        <source>Window</source>
+        <translation>Ikkuna</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Koko näyttö</translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>Tekijänoikeudet ja lisenssit kuvista</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Luo kuvat välilehdistä</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Lisenssitiedot</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>ON</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>POIS</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>Tallennusaika:</translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>Videon koko:</translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>Vapaa levytila:</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>Tietoja</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>Ikkuna</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Koko näyttö</translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>Alue</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>Videokoodekki</translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>Ruutuja</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Tallennusmuoto</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>Käytettävissä</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>Ei käytettävissä</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>Aloita</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>Lopeta</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>Tauko</translation>
+    </message>
+    <message>
+        <source>Continue</source>
+        <translation>Jatka</translation>
+    </message>
+    <message>
+        <source>Play</source>
+        <translation>Toista</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Kansio</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>Älä tallenna hiiren osoitinta</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -601,7 +725,7 @@
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>Toista</translation>
@@ -614,29 +738,5 @@
         <source>Stop</source>
         <translation>Lopeta</translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation>Avaa tiedosto</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Koko näyttö</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>Edellinen kehys</translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>Seuraava kehys</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>Mykistä</translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>Siirrä valikko</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
