@@ -13,6 +13,13 @@
         <translation>Caméra</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSettingsDialog</name>
+    <message>
+        <source>Camera settings</source>
+        <translation>Configuration caméra</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraSingle</name>
     <message>
@@ -78,6 +85,13 @@
         <translation>Amusez-vous bien avec vokoscreenNG</translation>
     </message>
 </context>
+<context>
+    <name>QvkDirDialog</name>
+    <message>
+        <source>Dialog</source>
+        <translation>Dialogue</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -132,14 +146,6 @@
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Plein écran</translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>Fenêtre</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
         <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
@@ -166,6 +172,25 @@
         <translation>Faire un don</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>Code source</translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>Page d&apos;accueil</translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>Traductions</translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>Faire un don</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
@@ -356,10 +381,6 @@
         <source>Audiocodec</source>
         <translation>Codec audio</translation>
     </message>
-    <message>
-        <source>Quality</source>
-        <translation>Qualité</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>Ne pas enregistrer le curseur de la souris</translation>
@@ -512,10 +533,6 @@
         <source>Remove window frame</source>
         <translation>Supprimer le cadre de la fenêtre </translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>Faire un don</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>Remise à zéro de tous les paramètres au prochain redémarrage du logiciel.</translation>
@@ -592,6 +609,113 @@
         <source>Seconds wait before recording</source>
         <translation>Secondes d&apos;attente avant l&apos;enregistrement</translation>
     </message>
+    <message>
+        <source>Window</source>
+        <translation>Fenêtre</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Plein écran</translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>Copyright et licence de la vidéo</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Créer des images d&apos;onglets</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Informations sur la licence</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>ON</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>OFF</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>Temps enregistré:</translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>Taille video:</translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>Espace disque libre:</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>Information</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>Fenêtre</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Plein écran</translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>Définir une zone manuellement</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>Codec vidéo</translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>Images</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Format</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>Disponible</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>Indisponible</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>Démarrer</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>Arrêter</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>Pause</translation>
+    </message>
+    <message>
+        <source>Continue</source>
+        <translation>Continuer</translation>
+    </message>
+    <message>
+        <source>Play</source>
+        <translation>Lire</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Dossier</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>Ne pas enregistrer le curseur de la souris</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -601,7 +725,7 @@
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>Lire</translation>
@@ -614,29 +738,5 @@
         <source>Stop</source>
         <translation>Arrêter</translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation>Ouvrir fichier</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Plein écran</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>Cadre précédent</translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>Cadre suivant</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>Muet</translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>Déplacer le menu</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
