@@ -13,6 +13,13 @@
         <translation>Kamera</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSettingsDialog</name>
+    <message>
+        <source>Camera settings</source>
+        <translation>Pengaturan Kamera</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraSingle</name>
     <message>
@@ -78,6 +85,13 @@
         <translation>Selamat bersenang-senang dengan vokoscreenNG</translation>
     </message>
 </context>
+<context>
+    <name>QvkDirDialog</name>
+    <message>
+        <source>Dialog</source>
+        <translation>Dialog</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -132,14 +146,6 @@
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Layar penuh</translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>Jendela</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
         <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
@@ -166,6 +172,25 @@
         <translation>Donasi</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>Kode sumber</translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>Halaman muka</translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>Terjemahan</translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>Donasi</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
@@ -356,10 +381,6 @@
         <source>Audiocodec</source>
         <translation>Kodekaudio</translation>
     </message>
-    <message>
-        <source>Quality</source>
-        <translation>Kualitas</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>Jangan rekam kursor tetikus</translation>
@@ -512,10 +533,6 @@
         <source>Remove window frame</source>
         <translation>Hilangkan bingkai jendela</translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>Donasi</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>Atur ulang semua pengaturan pada mulai berikutnya</translation>
@@ -592,6 +609,113 @@
         <source>Seconds wait before recording</source>
         <translation>detik waktu tunggu prarekam</translation>
     </message>
+    <message>
+        <source>Window</source>
+        <translation>Jendela</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Layar penuh</translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>Hak cipta dan lisensi dari gambar - gambar</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Buat gambar dari tab</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Informasi lisensi</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>HIDUPKAN</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>MATIKAN</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>Waktu Rekam:</translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>Ukuran video:</translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>Ruang bebas diska:</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>Informasi:</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>Jendela</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Layar penuh</translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>Bidangluas</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>Kodekvideo</translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>Frame</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Format</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>Tersedia</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>Tidak tersedia</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>Mulai</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>Berhenti</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>Jeda</translation>
+    </message>
+    <message>
+        <source>Continue</source>
+        <translation>Lanjut</translation>
+    </message>
+    <message>
+        <source>Play</source>
+        <translation>Putar</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Folder</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>Jangan rekam kursor tetikus</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -601,42 +725,18 @@
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>Putar</translation>
     </message>
     <message>
         <source>Pause</source>
-        <translation>Tangguhkan</translation>
+        <translation>Jeda</translation>
     </message>
     <message>
         <source>Stop</source>
         <translation>Berhenti</translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation>Buka Berkas</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Layar penuh</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>Bingkai sebelumnya</translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>Bingkai berikutnya</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>Bisu</translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>Pindah menu</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
