@@ -13,6 +13,13 @@
         <translation>Kamera</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSettingsDialog</name>
+    <message>
+        <source>Camera settings</source>
+        <translation>Pengaturan Kamera</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraSingle</name>
     <message>
@@ -78,6 +85,13 @@
         <translation>Bersenang-senanglah dengan vokoscreenNG</translation>
     </message>
 </context>
+<context>
+    <name>QvkDirDialog</name>
+    <message>
+        <source>Dialog</source>
+        <translation>Percakapan</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -132,14 +146,6 @@
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Layar penuh</translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>Jendela</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
         <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
@@ -166,6 +172,25 @@
         <translation>Donasi</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>Kode sumber</translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>Beranda</translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>Terjemahan</translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>Donasi</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
@@ -356,10 +381,6 @@
         <source>Audiocodec</source>
         <translation>AudioCodec</translation>
     </message>
-    <message>
-        <source>Quality</source>
-        <translation>Kualitas</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>Jangan rekam kursor mouse</translation>
@@ -512,10 +533,6 @@
         <source>Remove window frame</source>
         <translation>Hapus bingkai jendela</translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>Donasi</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>Setel ulang semua pengaturan di awal berikutnya</translation>
@@ -592,6 +609,113 @@
         <source>Seconds wait before recording</source>
         <translation>Beberapa detik menunggu sebelum merekam</translation>
     </message>
+    <message>
+        <source>Window</source>
+        <translation>Jendela</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Layar penuh</translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>Hak cipta dan lisensi dari gambar</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Buat gambar tab</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Informasi lisensi</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>NYALA</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>MATI</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>Waktu rekam:</translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>Ukuran video:</translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>Ruang disk kosong:</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>Informasi</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>Jendela</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Layar penuh</translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>Area</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>VideoCodec</translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>Bingkai</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Format</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>Tersedia</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>Tidak Tersedia</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>Mulai</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>Berhenti</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>Jeda</translation>
+    </message>
+    <message>
+        <source>Continue</source>
+        <translation>Lanjutkan</translation>
+    </message>
+    <message>
+        <source>Play</source>
+        <translation>Mainkan</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Folder</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>Jangan rekam kursor mouse</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -601,7 +725,7 @@
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>Mainkan</translation>
@@ -614,29 +738,5 @@
         <source>Stop</source>
         <translation>Berhenti</translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation>Buka file</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Layar penuh</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>Bingkai sebelumnya</translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>Bingkai berikutnya</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>Bisukan</translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>Pindahkan menu</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
