@@ -13,6 +13,13 @@
         <translation>Webcam</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSettingsDialog</name>
+    <message>
+        <source>Camera settings</source>
+        <translation>Impostazioni camera</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraSingle</name>
     <message>
@@ -78,6 +85,13 @@
         <translation>Buon divertimento con vokoscreenNG</translation>
     </message>
 </context>
+<context>
+    <name>QvkDirDialog</name>
+    <message>
+        <source>Dialog</source>
+        <translation>Finestra di dialogo Impostazioni fotocamera</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -132,14 +146,6 @@
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Schermo intero</translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>Finestra</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
         <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
@@ -166,6 +172,25 @@
         <translation>Fai una donazione</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>Codice sorgente</translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>Pagina iniziale</translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>Traduzioni</translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>Fai una donazione</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
@@ -356,10 +381,6 @@
         <source>Audiocodec</source>
         <translation>Codificatore audio</translation>
     </message>
-    <message>
-        <source>Quality</source>
-        <translation>Qualità</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>Non registrare il cursore del mouse</translation>
@@ -512,10 +533,6 @@
         <source>Remove window frame</source>
         <translation>Rimuovi bordo finestra</translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>Fai una donazione</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>Ripristina tutte le impostazioni al prossimo avvio</translation>
@@ -592,6 +609,113 @@
         <source>Seconds wait before recording</source>
         <translation>Secondi di attesa prima di registrare</translation>
     </message>
+    <message>
+        <source>Window</source>
+        <translation>Finestra</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Schermo intero</translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>Copyright e licenza immagini</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Crea immagini delle schede</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Informazioni sulla licenza</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>Acceso</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>Spento</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>Tempo di registrazione:</translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>Dimensioni video:</translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>Spazio disco libero:</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>Informazione</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>Finestra</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Schermo intero</translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>Area</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>Codifica video</translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>Fotogrammi</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Formato video</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>Disponibile</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>Non disponibile</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>Inizia</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>Ferma</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>Pausa</translation>
+    </message>
+    <message>
+        <source>Continue</source>
+        <translation>Continua</translation>
+    </message>
+    <message>
+        <source>Play</source>
+        <translation>Riproduci</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Cartella</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>Non registrare il cursore del mouse</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -601,7 +725,7 @@
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>Riproduci</translation>
@@ -614,29 +738,5 @@
         <source>Stop</source>
         <translation>Ferma</translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation>Apri file</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Schermo intero</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>Fermo immagine precedente</translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>Fermo immagine successivo</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>Silenzia</translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>Sposta menu</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
