@@ -14,7 +14,38 @@
     </message>
 </context>
 <context>
-    <name>QvkCameraWindow</name>
+    <name>QvkCameraSettingsDialog</name>
+    <message>
+        <source>Camera settings</source>
+        <translation>カメラの設定</translation>
+    </message>
+</context>
+<context>
+    <name>QvkCameraSingle</name>
+    <message>
+        <source>Remove window frame</source>
+        <translation>ウィンドウ枠非表示</translation>
+    </message>
+    <message>
+        <source>Flip vertical</source>
+        <translation>垂直反転</translation>
+    </message>
+    <message>
+        <source>Flip horizontal</source>
+        <translation>水平反転</translation>
+    </message>
+    <message>
+        <source>Invert</source>
+        <translation>ネガポジ反転</translation>
+    </message>
+    <message>
+        <source>Gray</source>
+        <translation>グレー</translation>
+    </message>
+    <message>
+        <source>Black-and-white</source>
+        <translation>白黒</translation>
+    </message>
     <message>
         <source>Switch to Window</source>
         <translation>ウィンドウ表示</translation>
@@ -24,19 +55,41 @@
         <translation>全画面表示</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraWindow</name>
+    <message>
+        <source>Switch to Window</source>
+        <translation>ウィンドウ表示</translation>
+    </message>
+    <message>
+        <source>Switch to Fullscreen</source>
+        <translation>全画面表示</translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation>カメラ</translation>
+    </message>
+</context>
 <context>
     <name>QvkCiscoFinishDialog</name>
     <message>
         <source>The setup was successful.</source>
-        <translation type="unfinished"/>
+        <translation>初期設定は完了しました。</translation>
     </message>
     <message>
         <source>Close this window and start vokoscreenNG again.</source>
-        <translation type="unfinished"/>
+        <translation>このウィンドウを閉じてvokoscreenNGを再度起動してください。</translation>
     </message>
     <message>
         <source>Have fun with vokoscreenNG</source>
-        <translation type="unfinished"/>
+        <translation>vokoscreenNGをお楽しみください</translation>
+    </message>
+</context>
+<context>
+    <name>QvkDirDialog</name>
+    <message>
+        <source>Dialog</source>
+        <translation>ダイアログ</translation>
     </message>
 </context>
 <context>
@@ -93,16 +146,9 @@
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation>全画面</translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>ウィンドウ</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
+        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
         <translation>ファイルマネージャーが見つかりません</translation>
     </message>
     <message>
@@ -126,6 +172,25 @@
         <translation>寄付</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>ソースコード</translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>ホームページ</translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>翻訳</translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>寄付</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
@@ -147,6 +212,17 @@
         <translation>範囲</translation>
     </message>
 </context>
+<context>
+    <name>QvkSnapshot</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>ファイルマネージャーが見つかりません</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>ファイルマネージャーをインストールしてください</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -209,6 +285,13 @@
         <translation>拡大</translation>
     </message>
 </context>
+<context>
+    <name>QvkWASAPIController</name>
+    <message>
+        <source>Select one or more devices</source>
+        <translation>一つ以上のデバイスを選択</translation>
+    </message>
+</context>
 <context>
     <name>cameraSettingsDialog</name>
     <message>
@@ -298,10 +381,6 @@
         <source>Audiocodec</source>
         <translation>音声コーデック</translation>
     </message>
-    <message>
-        <source>Quality</source>
-        <translation>品質</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>マウスカーソルを録画しない</translation>
@@ -406,10 +485,6 @@
         <source>Gray</source>
         <translation>グレー</translation>
     </message>
-    <message>
-        <source>Send Report</source>
-        <translation>レポート送信</translation>
-    </message>
     <message>
         <source>CTRL+SHIFT+F10</source>
         <translation>CTRL+SHIFT+F10</translation>
@@ -458,10 +533,6 @@
         <source>Remove window frame</source>
         <translation>ウィンドウ枠非表示</translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>寄付</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>次回起動時にすべての設定をリセットする</translation>
@@ -488,39 +559,162 @@
     </message>
     <message>
         <source>Automatically</source>
-        <translation type="unfinished"/>
+        <translation>自動的に</translation>
     </message>
     <message>
         <source>Create images of tabs </source>
-        <translation type="unfinished"/>
+        <translation>タブのイメージを作成</translation>
     </message>
     <message>
         <source>License information</source>
-        <translation type="unfinished"/>
+        <translation>ライセンス情報</translation>
     </message>
     <message>
         <source>ON</source>
-        <translation type="unfinished"/>
+        <translation>オン</translation>
     </message>
     <message>
         <source>OFF</source>
-        <translation type="unfinished"/>
+        <translation>オフ</translation>
     </message>
     <message>
         <source>Global keyboard shortcuts</source>
-        <translation type="unfinished"/>
+        <translation>共通キーボードショートカット</translation>
     </message>
     <message>
         <source>Assigned shortcut keys.</source>
-        <translation type="unfinished"/>
+        <translation>割り当てられたショートカットキー</translation>
     </message>
     <message>
         <source>Keyboard shortcut not assigned or assigned more than once.</source>
-        <translation type="unfinished"/>
+        <translation>一度割り当てられたキーを他のショートカットに割り当てることはできません。</translation>
     </message>
     <message>
         <source>If it shows assigned but does not work, it is being used by another program.</source>
-        <translation type="unfinished"/>
+        <translation>もし、割り当てられたように見えるのに動作しない場合は、他のプログラムによって使用されている可能性があります。</translation>
+    </message>
+    <message>
+        <source>Snapshot</source>
+        <translation>スナップショット</translation>
+    </message>
+    <message>
+        <source>Imagepath</source>
+        <translation>画像のパス</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>このウィンドウを隠す</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>記録開始までの待機秒数</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>ウィンドウ</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>全画面</translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>画像の著作権およびライセンス</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>タブのイメージを作成</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>ライセンス情報</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>オン</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>オフ</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>録画時間:</translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>動画サイズ</translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>空きディスク領域:</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>情報</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>ウィンドウ</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>全画面</translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>範囲</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>動画コーデック</translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>フレーム</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>形式</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>利用可能</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>利用不可</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>開始</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>停止</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>一時停止</translation>
+    </message>
+    <message>
+        <source>Continue</source>
+        <translation>持続する</translation>
+    </message>
+    <message>
+        <source>Play</source>
+        <translation>再生</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>フォルダー</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>マウスカーソルを録画しない</translation>
     </message>
 </context>
 <context>
@@ -531,7 +725,7 @@
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>再生</translation>
@@ -544,29 +738,5 @@
         <source>Stop</source>
         <translation>停止</translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation>ファイルを開く</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>全画面</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>前のフレーム</translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>次のフレーム</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>ミュート</translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>移動</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
