@@ -13,6 +13,13 @@
         <translation>Kamera</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSettingsDialog</name>
+    <message>
+        <source>Camera settings</source>
+        <translation>Kameros nustatymai</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraSingle</name>
     <message>
@@ -78,6 +85,13 @@
         <translation>Gero laiko su vokoscreenNG</translation>
     </message>
 </context>
+<context>
+    <name>QvkDirDialog</name>
+    <message>
+        <source>Dialog</source>
+        <translation>Dialogas</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -132,14 +146,6 @@
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Visas ekranas</translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>Langas</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
         <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
@@ -166,6 +172,25 @@
         <translation>Paaukoti</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>Pirminis kodas</translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>Svetainė</translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>Vertimai</translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>Paaukoti</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
@@ -356,10 +381,6 @@
         <source>Audiocodec</source>
         <translation>Garso kodekas</translation>
     </message>
-    <message>
-        <source>Quality</source>
-        <translation>Kokybė</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>Neįrašinėti pelės žymeklio</translation>
@@ -512,10 +533,6 @@
         <source>Remove window frame</source>
         <translation>Šalinti lango rėmelį</translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>Paaukoti</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>Kito paleidimo metu atstatyti visus nustatymus</translation>
@@ -592,6 +609,113 @@
         <source>Seconds wait before recording</source>
         <translation>Kiek sekundžių laukti, prieš įrašinėjant</translation>
     </message>
+    <message>
+        <source>Window</source>
+        <translation>Langas</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Visas ekranas</translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>Autorių teisės ir licencijos iš paveikslų</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Sukurti kortelių paveikslus</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Informacija apie licenciją</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>ĮJUNGTA</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>IŠJUNGTA</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>Įrašinėjimo laikas:</translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>Vaizdo dydis:</translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>Laisva vieta diske:</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>Informacija</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>Langas</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Visas ekranas</translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>Sritis</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>Vaizdo kodekas</translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>Kadrai</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Formatas</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>Prieinama</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>Neprieinama</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>Pradėti</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>Stabdyti</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>Pristabdyti</translation>
+    </message>
+    <message>
+        <source>Continue</source>
+        <translation>Tęsti</translation>
+    </message>
+    <message>
+        <source>Play</source>
+        <translation>Groti</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Aplankas</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>Neįrašinėti pelės žymeklio</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -601,7 +725,7 @@
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>Groti</translation>
@@ -614,29 +738,5 @@
         <source>Stop</source>
         <translation>Stabdyti</translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation>Atverti failą</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Visas ekranas</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>Ankstesnis kadras</translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>Kitas kadras</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>Nutildyti</translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>Perkelti meniu</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
