@@ -13,6 +13,13 @@
         <translation>Kamera</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSettingsDialog</name>
+    <message>
+        <source>Camera settings</source>
+        <translation>Kamera instillinger</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraSingle</name>
     <message>
@@ -78,6 +85,13 @@
         <translation>Ha det gøy med vokoscreenNG</translation>
     </message>
 </context>
+<context>
+    <name>QvkDirDialog</name>
+    <message>
+        <source>Dialog</source>
+        <translation>Dialog</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -132,14 +146,6 @@
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Fullskjerm</translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>Vindu</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
         <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
@@ -166,6 +172,25 @@
         <translation>Donasjon</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>Sourcekode</translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>Hjemmeside</translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>Oversettelser</translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>Donasjon</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
@@ -356,10 +381,6 @@
         <source>Audiocodec</source>
         <translation>Lydkodek</translation>
     </message>
-    <message>
-        <source>Quality</source>
-        <translation>Kvalitet</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>ikke ta opp musepeker</translation>
@@ -512,10 +533,6 @@
         <source>Remove window frame</source>
         <translation>Fjern vindusramme</translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>Donasjon</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>Nullstille alle innstillinger ved neste oppstart</translation>
@@ -592,6 +609,113 @@
         <source>Seconds wait before recording</source>
         <translation>Sekunder venter før opptak</translation>
     </message>
+    <message>
+        <source>Window</source>
+        <translation>Vindu</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Fullskjerm</translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>Opphavsrett og lisens fra bilder</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Lag bilder av faner</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Lisensinformasjon</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>PÅ</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>AV</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>Opptakstid:</translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>Videostørrelse:</translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>Ledig diskplass:</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>Informasjon</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>Vindu</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Fullskjerm</translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>Område</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>Videokodek</translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>Rammer</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Format</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>Tilgjengelig</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>Ikke tilgjengelig</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>Start</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>Stoppe</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>Pause</translation>
+    </message>
+    <message>
+        <source>Continue</source>
+        <translation>Fortsett</translation>
+    </message>
+    <message>
+        <source>Play</source>
+        <translation>Spille</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Mappe</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>ikke ta opp musepeker</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -601,7 +725,7 @@
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>Spille</translation>
@@ -614,29 +738,5 @@
         <source>Stop</source>
         <translation>Stoppe</translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation>Åpne Fil</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Fullskjerm</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>Forrige bilde</translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>Neste bilde</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>Stilne</translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>Flytt meny</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
