@@ -13,6 +13,13 @@
         <translation>Camera</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSettingsDialog</name>
+    <message>
+        <source>Camera settings</source>
+        <translation>Camera instellingen</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraSingle</name>
     <message>
@@ -78,6 +85,13 @@
         <translation>Veel plezier met vokoscreenNG</translation>
     </message>
 </context>
+<context>
+    <name>QvkDirDialog</name>
+    <message>
+        <source>Dialog</source>
+        <translation>Dialoogvenster</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -132,14 +146,6 @@
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Volledig scherm</translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>Venster</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
         <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
@@ -166,6 +172,25 @@
         <translation>Doneren</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>Broncode</translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>Website</translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>Vertalingen</translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>Doneren</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
@@ -356,10 +381,6 @@
         <source>Audiocodec</source>
         <translation>Audiocodec</translation>
     </message>
-    <message>
-        <source>Quality</source>
-        <translation>Kwaliteit</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>Muis cursor niet opnemen</translation>
@@ -512,10 +533,6 @@
         <source>Remove window frame</source>
         <translation>Vensterrand verwijderen</translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>Doneren</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>Alle instellingen herstellen bij opnieuw opstarten</translation>
@@ -592,6 +609,113 @@
         <source>Seconds wait before recording</source>
         <translation>Aantal seconden voordat opname start</translation>
     </message>
+    <message>
+        <source>Window</source>
+        <translation>Venster</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Volledig scherm</translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>Copyright en licentie uit afbeeldingen</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Afbeeldingen maken van tabbladen</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Licentie informatie</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>AAN</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>UIT</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>Opnametijd:</translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>Videoformaat:</translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>Vrije schijfruimte:</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>Informatie</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>Venster</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Volledig scherm</translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>Gebied</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>Videocodec</translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>Frames</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Formaat</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>Beschikbaar</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>Niet beschikbaar</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>Start</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>Stop</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>Pauze</translation>
+    </message>
+    <message>
+        <source>Continue</source>
+        <translation>Hervatten</translation>
+    </message>
+    <message>
+        <source>Play</source>
+        <translation>Afspelen</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Map</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>Muis cursor niet opnemen</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -601,42 +725,18 @@
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>Afspelen</translation>
     </message>
     <message>
         <source>Pause</source>
-        <translation>Pauzeren</translation>
+        <translation>Pauze</translation>
     </message>
     <message>
         <source>Stop</source>
         <translation>Stop</translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation>Bestand openen</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Volledig scherm</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>Vorig frame</translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>Volgend frame</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>Dempen</translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>Menu verplaatsen</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
