@@ -13,6 +13,13 @@
         <translation>Kamera</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSettingsDialog</name>
+    <message>
+        <source>Camera settings</source>
+        <translation>Ustawienia kamery</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraSingle</name>
     <message>
@@ -78,6 +85,13 @@
         <translation>Baw się dobrze z vokoscreenNG</translation>
     </message>
 </context>
+<context>
+    <name>QvkDirDialog</name>
+    <message>
+        <source>Dialog</source>
+        <translation>Dialog</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -132,14 +146,6 @@
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Pełny ekran</translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>Okno</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
         <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
@@ -166,6 +172,25 @@
         <translation>Darowizna</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>Kod źródłowy</translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>Strona domowa</translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>Tłumaczenia</translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>Darowizna</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
@@ -356,10 +381,6 @@
         <source>Audiocodec</source>
         <translation>Kodek audio</translation>
     </message>
-    <message>
-        <source>Quality</source>
-        <translation>Jakość</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>Nie nagrywaj kursora myszy</translation>
@@ -512,10 +533,6 @@
         <source>Remove window frame</source>
         <translation>Usuń ramkę okna</translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>Darowizna</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>Zresetuj ustawienia przy następnym uruchomieniu</translation>
@@ -592,6 +609,113 @@
         <source>Seconds wait before recording</source>
         <translation>Sekundy oczekiwania przed rozpoczęciem nagrania</translation>
     </message>
+    <message>
+        <source>Window</source>
+        <translation>Okno</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Pełny ekran</translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>Prawa autorskie i licencja z obrazu</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Wykonaj rzut obrazu kart</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Informacja o licencji</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>WŁ.</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>WYŁ.</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>Czas nagrania:</translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>Rozmiar wideo:</translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>Wolne miejsce na dysku:</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>Informacje</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>Okno</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Pełny ekran</translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>Obszar</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>Kodek wideo</translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>Klatki</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Format</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>Dostępne</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>Niedostępne</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>Start</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>Stop</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>Pauza</translation>
+    </message>
+    <message>
+        <source>Continue</source>
+        <translation>Kontynuuj</translation>
+    </message>
+    <message>
+        <source>Play</source>
+        <translation>Odtwórz</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Folder</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>Nie nagrywaj kursora myszy</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -601,7 +725,7 @@
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>Odtwórz</translation>
@@ -614,29 +738,5 @@
         <source>Stop</source>
         <translation>Stop</translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation>Otwórz plik</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Pełny ekran</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>Poprzednia klatka</translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>Następna klatka</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>Wycisz</translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>Przesuń menu</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
