@@ -10,7 +10,14 @@
     <name>QvkCameraController</name>
     <message>
         <source>Camera</source>
-        <translation>Camera</translation>
+        <translation>Câmara</translation>
+    </message>
+</context>
+<context>
+    <name>QvkCameraSettingsDialog</name>
+    <message>
+        <source>Camera settings</source>
+        <translation>Configurações da câmara</translation>
     </message>
 </context>
 <context>
@@ -45,7 +52,7 @@
     </message>
     <message>
         <source>Switch to Fullscreen</source>
-        <translation>Mudar para ecrã inteiro</translation>
+        <translation>Mudar para o ecrã completo</translation>
     </message>
 </context>
 <context>
@@ -60,14 +67,14 @@
     </message>
     <message>
         <source>Camera</source>
-        <translation>Camera</translation>
+        <translation>Câmara</translation>
     </message>
 </context>
 <context>
     <name>QvkCiscoFinishDialog</name>
     <message>
         <source>The setup was successful.</source>
-        <translation>A configuração foi bem sucedida.</translation>
+        <translation>A instalação foi bem sucedida.</translation>
     </message>
     <message>
         <source>Close this window and start vokoscreenNG again.</source>
@@ -78,6 +85,13 @@
         <translation>Divirta-se com vokoscreenNG</translation>
     </message>
 </context>
+<context>
+    <name>QvkDirDialog</name>
+    <message>
+        <source>Dialog</source>
+        <translation>Diálogo</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -96,7 +110,7 @@
     <name>QvkImageFromTabs</name>
     <message>
         <source>No filemanager found.</source>
-        <translation>Não foi encontrado nenhum gestor de ficheiros.</translation>
+        <translation>Nenhum gestor de ficheiros encontrado.</translation>
     </message>
     <message>
         <source>Please install a filemanager.</source>
@@ -111,11 +125,11 @@
     </message>
     <message>
         <source>The recording is not started, not enough free disk space.</source>
-        <translation>A gravação não é iniciada, não há espaço livre em disco suficiente.</translation>
+        <translation>A gravação não foi iniciada, não há espaço livre suficiente no disco.</translation>
     </message>
     <message>
         <source>The free disk space limit is reached.</source>
-        <translation>Foi alcançado o limite de espaço em disco.</translation>
+        <translation>O limite de espaço livre em disco foi atingido.</translation>
     </message>
     <message>
         <source>Limit of free disk space</source>
@@ -127,23 +141,15 @@
     </message>
     <message>
         <source>The recording was stopped, not enough free disk space.</source>
-        <translation>A gravação foi parada, sem espaço em disco disponível.</translation>
+        <translation>A gravação foi interrompida porque não havia espaço livre suficiente no disco.</translation>
     </message>
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Ecrã inteiro</translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>Janela</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
         <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
-        <translation>Nenhum gestor de ficheiros encontrado.</translation>
+        <translation>Não foi encontrado um gestor de ficheiros.</translation>
     </message>
     <message>
         <source>Please install a filemanager.</source>
@@ -166,6 +172,25 @@
         <translation>Doar</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>Código-fonte</translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>Página inicial</translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>Traduções</translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>Doar</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
@@ -222,7 +247,7 @@
     </message>
     <message>
         <source>Camera</source>
-        <translation>Camera</translation>
+        <translation>Câmara</translation>
     </message>
     <message>
         <source>Magnification</source>
@@ -253,7 +278,7 @@
     </message>
     <message>
         <source>Camera</source>
-        <translation>Camera</translation>
+        <translation>Câmara</translation>
     </message>
     <message>
         <source>Magnification</source>
@@ -310,7 +335,7 @@
     </message>
     <message>
         <source>Reset</source>
-        <translation>Restabelecer</translation>
+        <translation>Reiniciar</translation>
     </message>
     <message>
         <source>Magnification</source>
@@ -356,10 +381,6 @@
         <source>Audiocodec</source>
         <translation>Codec de áudio</translation>
     </message>
-    <message>
-        <source>Quality</source>
-        <translation>Qualidade</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>Não gravar o cursor do rato</translation>
@@ -512,10 +533,6 @@
         <source>Remove window frame</source>
         <translation>Remover a moldura da janela</translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>Doar</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>Repor todas as configurações no próximo início</translation>
@@ -592,6 +609,113 @@
         <source>Seconds wait before recording</source>
         <translation>Espera em segundos antes de gravar</translation>
     </message>
+    <message>
+        <source>Window</source>
+        <translation>Janela</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Ecrã inteiro</translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>Direitos de autor e licença das imagens</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Criar imagens de guias</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Informação de licença</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>ON</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>OFF</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>Tempo de gravação:</translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>Tamanho do vídeo:</translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>Espaço de disco disponível:</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>Informação</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>Janela</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Ecrã inteiro</translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>Área</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>Codec de vídeo</translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>Imagens</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Formato</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>Disponível</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>Indisponível</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>Iniciar</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>Parar</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>Pausa</translation>
+    </message>
+    <message>
+        <source>Continue</source>
+        <translation>Continuar</translation>
+    </message>
+    <message>
+        <source>Play</source>
+        <translation>Reproduzir</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Pasta</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>Não gravar o cursor do rato</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -601,7 +725,7 @@
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>Reproduzir</translation>
@@ -614,29 +738,5 @@
         <source>Stop</source>
         <translation>Parar</translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation>Abrir Ficheiro</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Ecrã inteiro</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>Imagem anterior</translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>Imagem seguinte</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>Mudo</translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>Mover o menu</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
