@@ -13,6 +13,13 @@
         <translation>Câmera</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSettingsDialog</name>
+    <message>
+        <source>Camera settings</source>
+        <translation>Configurações da câmera</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraSingle</name>
     <message>
@@ -78,6 +85,13 @@
         <translation>Divirta-se com o vokoscreenNG!</translation>
     </message>
 </context>
+<context>
+    <name>QvkDirDialog</name>
+    <message>
+        <source>Dialog</source>
+        <translation>Diálogo</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -132,14 +146,6 @@
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Tela cheia</translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>Janela</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
         <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
@@ -166,6 +172,25 @@
         <translation>Doações</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>Código-Fonte</translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>Homepage</translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>Traduções</translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>Doações</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
@@ -356,10 +381,6 @@
         <source>Audiocodec</source>
         <translation>Codec de áudio</translation>
     </message>
-    <message>
-        <source>Quality</source>
-        <translation>Qualidade</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>Não gravar o cursor do mouse</translation>
@@ -512,10 +533,6 @@
         <source>Remove window frame</source>
         <translation>Remover moldura da janela</translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>Doações</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>Redefinir todas as configurações na próxima inicialização</translation>
@@ -592,6 +609,113 @@
         <source>Seconds wait before recording</source>
         <translation>Aguarde segundos antes de gravar</translation>
     </message>
+    <message>
+        <source>Window</source>
+        <translation>Janela</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Tela cheia</translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>Direitos autorais e licença das imagens</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Criar imagens das abas</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Infomações de Licença</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>LIGADO</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>DESLIGADO</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>Tempo de gravação:</translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>Tamanho do vídeo:</translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>Espaço disponível no disco:</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>Informação</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>Janela</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Tela cheia</translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>Área</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>Codec de vídeo </translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>Quadros</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Formato</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>Disponível</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>Não disponível</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>Iniciar</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>Parar</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>Pausar</translation>
+    </message>
+    <message>
+        <source>Continue</source>
+        <translation>Continuar</translation>
+    </message>
+    <message>
+        <source>Play</source>
+        <translation>Reproduzir</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Pasta</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>Não gravar o cursor do mouse</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -601,7 +725,7 @@
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>Reproduzir</translation>
@@ -614,29 +738,5 @@
         <source>Stop</source>
         <translation>Parar</translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation>Abrir Arquivo</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Tela cheia</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>Quadro anterior</translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>Próximo quadro</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>Mudo</translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>Mover o menu</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
