@@ -13,6 +13,13 @@
         <translation>Камера</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSettingsDialog</name>
+    <message>
+        <source>Camera settings</source>
+        <translation>Параметры камеры</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraSingle</name>
     <message>
@@ -78,6 +85,13 @@
         <translation>Получайте удовольствие от vokoscreenNG</translation>
     </message>
 </context>
+<context>
+    <name>QvkDirDialog</name>
+    <message>
+        <source>Dialog</source>
+        <translation>Диалоговое окно</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -132,14 +146,6 @@
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Весь экран</translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>Окно</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
         <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
@@ -166,6 +172,25 @@
         <translation>Пожертвовать</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>Исходный код</translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>Веб-сайт</translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>Переводы</translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>Пожертвовать</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
@@ -356,10 +381,6 @@
         <source>Audiocodec</source>
         <translation>Звуковой кодек</translation>
     </message>
-    <message>
-        <source>Quality</source>
-        <translation>Качество</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>Не записывать указатель мыши</translation>
@@ -512,10 +533,6 @@
         <source>Remove window frame</source>
         <translation>Убрать рамку окна</translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>Пожертвовать</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>Сбросить все настройки при следующем запуске</translation>
@@ -592,6 +609,113 @@
         <source>Seconds wait before recording</source>
         <translation>Секунды ожидания перед записью</translation>
     </message>
+    <message>
+        <source>Window</source>
+        <translation>Окно</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Весь экран</translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>Авторское право и лицензия на использование изображений</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Создать изображения вкладок </translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Сведения о лицензии</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>Включить</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>Выключить</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>Время записи:</translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>Размер видео:</translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>Свободное место на диске:</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>Информация</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>Окно</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Весь экран</translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>Область экрана</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>Видеокодек</translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>Кадры</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Формат</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>Доступно</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>Недоступно</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>Начать</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>Остановить</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>Приостановить</translation>
+    </message>
+    <message>
+        <source>Continue</source>
+        <translation>Продолжить</translation>
+    </message>
+    <message>
+        <source>Play</source>
+        <translation>Воспроизвести</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Папка</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>Не записывать указатель мыши</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -601,7 +725,7 @@
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>Воспроизвести</translation>
@@ -614,29 +738,5 @@
         <source>Stop</source>
         <translation>Остановить</translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation>Открыть файл</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Весь экран</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>Предыдущий кадр</translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>Следующий кадр</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>Без звука</translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>Переместить меню</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
