@@ -13,6 +13,13 @@
         <translation>Kamera</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSettingsDialog</name>
+    <message>
+        <source>Camera settings</source>
+        <translation>Nastavenia kamery</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraSingle</name>
     <message>
@@ -78,6 +85,13 @@
         <translation>Zabávajte sa s vokoscreenNG</translation>
     </message>
 </context>
+<context>
+    <name>QvkDirDialog</name>
+    <message>
+        <source>Dialog</source>
+        <translation>Dialóg</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -132,14 +146,6 @@
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Celá obrazovka</translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>Okno</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
         <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
@@ -166,6 +172,25 @@
         <translation>Podporiť</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>Zdrojový kód</translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>Domovská stránka</translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>Preklady</translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>Podporiť</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
@@ -356,10 +381,6 @@
         <source>Audiocodec</source>
         <translation>Zvukový kódek</translation>
     </message>
-    <message>
-        <source>Quality</source>
-        <translation>Kvalita</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>Nenahrávať kurzor myši</translation>
@@ -512,10 +533,6 @@
         <source>Remove window frame</source>
         <translation>Odstrániť orámovanie okna</translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>Podporiť</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>Resetovať všetky nastavenia pri nasledujúcom štarte</translation>
@@ -592,6 +609,113 @@
         <source>Seconds wait before recording</source>
         <translation>Sekundy pred nahrávaním</translation>
     </message>
+    <message>
+        <source>Window</source>
+        <translation>Okno</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Celá obrazovka</translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>Copyright a licencie obrázkov</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Vytvoriť obrázky tabuliek</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Informácie o licencii</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>ZAP.</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>VYP.</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>Čas nahrávania:</translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>Veľkosť videa:</translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>Voľné miesto na disku:</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>Informácia</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>Okno</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Celá obrazovka</translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>Oblasť</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>Kódek video</translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>Snímky</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Formát</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>Je k dispozícii</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>Nie je k dispozícii</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>Štart</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>Stop</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>Pauza</translation>
+    </message>
+    <message>
+        <source>Continue</source>
+        <translation>Pokračovať</translation>
+    </message>
+    <message>
+        <source>Play</source>
+        <translation>Prehrať</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Priečinok - adresár</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>Nenahrávať kurzor myši</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -601,7 +725,7 @@
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>Prehrať</translation>
@@ -614,29 +738,5 @@
         <source>Stop</source>
         <translation>Stop</translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation>Otvoriť súbor</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Celá obrazovka</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>Predchádzajúce políčko</translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>Nasledujúce políčko</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>Stíšiť</translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>Premiestniť menu</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
