@@ -13,6 +13,13 @@
         <translation>Kamera</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSettingsDialog</name>
+    <message>
+        <source>Camera settings</source>
+        <translation>Подешавања камере</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraSingle</name>
     <message>
@@ -78,6 +85,13 @@
         <translation>Забави се са vokoscreenNG</translation>
     </message>
 </context>
+<context>
+    <name>QvkDirDialog</name>
+    <message>
+        <source>Dialog</source>
+        <translation>Дијалог</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -132,14 +146,6 @@
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Пун екран</translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>Прозор</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
         <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
@@ -166,6 +172,25 @@
         <translation>Донирај</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>Изворни код</translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>Почетна</translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>Преводи</translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>Донирај</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
@@ -356,10 +381,6 @@
         <source>Audiocodec</source>
         <translation>Аудио кодек</translation>
     </message>
-    <message>
-        <source>Quality</source>
-        <translation>Квалитет</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>Немој снимати стрелицу</translation>
@@ -512,10 +533,6 @@
         <source>Remove window frame</source>
         <translation>Уклони оквир прозора</translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>Донирај</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>Врати све на фабричка подешавања када следећи пут снимање почне </translation>
@@ -592,6 +609,113 @@
         <source>Seconds wait before recording</source>
         <translation>Секунде пре почетка снимања</translation>
     </message>
+    <message>
+        <source>Window</source>
+        <translation>Прозор</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Пун екран</translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>Ауторска права и лиценца од слика</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Креирај слике картица</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Информације о лиценци</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>Укључи</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>Искључи</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>Сними време:</translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>Величина видеа</translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>Слободан простор на диску</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>Информације</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>Прозор</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Пун екран</translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>Подручје</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>Видео кодек</translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>Фрејмови</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Формат</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>Доступно</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>Није доступно</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>Старт</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>Стоп</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>Пауза</translation>
+    </message>
+    <message>
+        <source>Continue</source>
+        <translation>Настави</translation>
+    </message>
+    <message>
+        <source>Play</source>
+        <translation>Почни</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Фасцикла</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>Немој снимати стрелицу</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -601,7 +725,7 @@
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>Почни</translation>
@@ -614,29 +738,5 @@
         <source>Stop</source>
         <translation>Стоп</translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation>Отвори документ</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Пун екран</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>Прошли кадар</translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>Следећи кадар</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>Нем</translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>Помери мени</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
