@@ -13,6 +13,13 @@
         <translation>Kamera</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSettingsDialog</name>
+    <message>
+        <source>Camera settings</source>
+        <translation>Kamerainställningar</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraSingle</name>
     <message>
@@ -78,6 +85,13 @@
         <translation>Ha så kul med vokoscreenNG</translation>
     </message>
 </context>
+<context>
+    <name>QvkDirDialog</name>
+    <message>
+        <source>Dialog</source>
+        <translation>Dialog</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -132,14 +146,6 @@
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Helskärm</translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>Fönster</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
         <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
@@ -166,6 +172,25 @@
         <translation>Donera</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>Källkod</translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>Hemsida</translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>Översättningar</translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>Donera</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
@@ -356,10 +381,6 @@
         <source>Audiocodec</source>
         <translation>Ljudkodek</translation>
     </message>
-    <message>
-        <source>Quality</source>
-        <translation>Kvalitet</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>Spela inte in muspekaren</translation>
@@ -512,10 +533,6 @@
         <source>Remove window frame</source>
         <translation>Ta bort fönsterram</translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>Donera</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>Återställ alla inställningar vid nästa programstart</translation>
@@ -592,6 +609,113 @@
         <source>Seconds wait before recording</source>
         <translation>Sekunders väntetid före inspelning</translation>
     </message>
+    <message>
+        <source>Window</source>
+        <translation>Fönster</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Helskärm</translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>Copyright och licens från bilder</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Skapa bilder av flikar</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Licensinformation</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>PÅ</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>AV</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>Inspelningstid:</translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>Videostorlek:</translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>Ledigt diskutrymme:</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>Information</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>Fönster</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Helskärm</translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>Område</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>Videokodek</translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>Bildrutor</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Format</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>Tillgänglig</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>Inte tillgänglig</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>Starta</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>Stoppa</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>Pausa</translation>
+    </message>
+    <message>
+        <source>Continue</source>
+        <translation>Fortsätt</translation>
+    </message>
+    <message>
+        <source>Play</source>
+        <translation>Spela upp</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Mapp</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>Spela inte in muspekaren</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -601,7 +725,7 @@
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>Spela upp</translation>
@@ -614,29 +738,5 @@
         <source>Stop</source>
         <translation>Stoppa</translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation>Öppna fil</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Helskärm</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>Föregående bildruta</translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>Nästa bildruta</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>Tyst</translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>Flytta menyn</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
