@@ -13,6 +13,13 @@
         <translation>Камера</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSettingsDialog</name>
+    <message>
+        <source>Camera settings</source>
+        <translation>Налаштування камери</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraSingle</name>
     <message>
@@ -78,6 +85,13 @@
         <translation>Розважайтеся з vokoscreenNG</translation>
     </message>
 </context>
+<context>
+    <name>QvkDirDialog</name>
+    <message>
+        <source>Dialog</source>
+        <translation>Діалогове вікно</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -132,14 +146,6 @@
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Увесь екран</translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>Вікно</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
         <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
@@ -166,6 +172,25 @@
         <translation>Зробити внесок</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>Джерельний код</translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>Вебсайт</translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>Переклади</translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>Зробити внесок</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
@@ -356,10 +381,6 @@
         <source>Audiocodec</source>
         <translation>Авдіокодек</translation>
     </message>
-    <message>
-        <source>Quality</source>
-        <translation>Якість</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>Не записувати вказівник миші</translation>
@@ -512,10 +533,6 @@
         <source>Remove window frame</source>
         <translation>Прибрати рамку вікна</translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>Зробити внесок</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>Скинути усі налаштування при наступному старті</translation>
@@ -592,6 +609,113 @@
         <source>Seconds wait before recording</source>
         <translation>Зачекати секунду перед записуванням</translation>
     </message>
+    <message>
+        <source>Window</source>
+        <translation>Вікно</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Увесь екран</translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>Авторські права та ліцензія на зображення</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>Створення зображень вкладок</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>Інформація про ліцензію</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>УВІМК</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>ВИМК</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>Час запису:</translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>Розмір відеофайлу: </translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>Вільне місце на диску: </translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>Інформація</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>Вікно</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>Увесь екран</translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>Довільна область</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>Відеокодек</translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>Кадри</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>Формат</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>Доступний</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>Недоступний</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>Почати</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>Зупинити</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>Призупинити</translation>
+    </message>
+    <message>
+        <source>Continue</source>
+        <translation>Продовжити</translation>
+    </message>
+    <message>
+        <source>Play</source>
+        <translation>Програти</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>Тека</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>Не записувати вказівник миші</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -601,7 +725,7 @@
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>Програти</translation>
@@ -614,29 +738,5 @@
         <source>Stop</source>
         <translation>Зупинити</translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation>Відкрити файл</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Увесь екран</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>Попередній кадр</translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>Наступний кадр</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>Без звуку</translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>Перемістити меню</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
