@@ -13,6 +13,13 @@
         <translation>摄像头</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSettingsDialog</name>
+    <message>
+        <source>Camera settings</source>
+        <translation>摄像头设置</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraSingle</name>
     <message>
@@ -78,6 +85,13 @@
         <translation>vokoscreenNG祝你玩得开心</translation>
     </message>
 </context>
+<context>
+    <name>QvkDirDialog</name>
+    <message>
+        <source>Dialog</source>
+        <translation>对话框</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -132,14 +146,6 @@
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation>全屏模式</translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>窗口</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
         <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
@@ -166,6 +172,25 @@
         <translation>捐赠</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>源代码</translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>网站</translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>翻译</translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>捐赠</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
@@ -356,10 +381,6 @@
         <source>Audiocodec</source>
         <translation>音频编码</translation>
     </message>
-    <message>
-        <source>Quality</source>
-        <translation>质量</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>不要录制鼠标</translation>
@@ -512,10 +533,6 @@
         <source>Remove window frame</source>
         <translation>移除窗口边框</translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>捐赠</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>下次启动时重置所有设置</translation>
@@ -592,6 +609,113 @@
         <source>Seconds wait before recording</source>
         <translation>开始录制前请等待数秒</translation>
     </message>
+    <message>
+        <source>Window</source>
+        <translation>窗口</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>全屏模式</translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>图片版权和许可条款</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>创建标签图像</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>许可证信息</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>开</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>关</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>录制时间:</translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>视频大小:</translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>可用磁盘空间:</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>信息</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>窗口</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>全屏模式</translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>区域</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>视频编码</translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>帧率</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>格式</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>可用</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>不可用</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>开始</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>停止</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>暂停</translation>
+    </message>
+    <message>
+        <source>Continue</source>
+        <translation>继续</translation>
+    </message>
+    <message>
+        <source>Play</source>
+        <translation>播放</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>文件夹</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>不要录制鼠标</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -601,7 +725,7 @@
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>播放</translation>
@@ -614,29 +738,5 @@
         <source>Stop</source>
         <translation>停止</translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation>打开文件</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>全屏模式</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>上一帧</translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>下一帧</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>静音</translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>移动菜单</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
