@@ -13,6 +13,13 @@
         <translation>攝影機</translation>
     </message>
 </context>
+<context>
+    <name>QvkCameraSettingsDialog</name>
+    <message>
+        <source>Camera settings</source>
+        <translation>攝影機設定</translation>
+    </message>
+</context>
 <context>
     <name>QvkCameraSingle</name>
     <message>
@@ -78,6 +85,13 @@
         <translation>祝使用vokoscreenNG愉快</translation>
     </message>
 </context>
+<context>
+    <name>QvkDirDialog</name>
+    <message>
+        <source>Dialog</source>
+        <translation>對話匣</translation>
+    </message>
+</context>
 <context>
     <name>QvkDirectSoundController</name>
     <message>
@@ -132,14 +146,6 @@
 </context>
 <context>
     <name>QvkMainWindow</name>
-    <message>
-        <source>Fullscreen</source>
-        <translation>全螢幕</translation>
-    </message>
-    <message>
-        <source>Window</source>
-        <translation>視窗</translation>
-    </message>
     <message>
         <source>No filemanager found.</source>
         <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
@@ -166,6 +172,25 @@
         <translation>捐款支持</translation>
     </message>
 </context>
+<context>
+    <name>QvkMainWindow_wl</name>
+    <message>
+        <source>Sourcecode</source>
+        <translation>來源程式碼</translation>
+    </message>
+    <message>
+        <source>Homepage</source>
+        <translation>官方網頁</translation>
+    </message>
+    <message>
+        <source>Translations</source>
+        <translation>軟體介面翻譯</translation>
+    </message>
+    <message>
+        <source>Donate</source>
+        <translation>捐款支持</translation>
+    </message>
+</context>
 <context>
     <name>QvkPulseAudioWatcher</name>
     <message>
@@ -356,10 +381,6 @@
         <source>Audiocodec</source>
         <translation>音訊編碼</translation>
     </message>
-    <message>
-        <source>Quality</source>
-        <translation>品質</translation>
-    </message>
     <message>
         <source>Do not record mouse cursor</source>
         <translation>不要錄製滑鼠游標</translation>
@@ -512,10 +533,6 @@
         <source>Remove window frame</source>
         <translation>移除視窗外框</translation>
     </message>
-    <message>
-        <source>Donate</source>
-        <translation>捐款支持</translation>
-    </message>
     <message>
         <source>Reset all settings at the next start</source>
         <translation>下次開啟時，重設所有設定</translation>
@@ -592,6 +609,113 @@
         <source>Seconds wait before recording</source>
         <translation>開始錄製前等待之秒數</translation>
     </message>
+    <message>
+        <source>Window</source>
+        <translation>視窗</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>全螢幕</translation>
+    </message>
+</context>
+<context>
+    <name>formMainWindow_wl</name>
+    <message>
+        <source>Copyright and license from pictures</source>
+        <translation>圖片的版權及授權條款</translation>
+    </message>
+    <message>
+        <source>Create images of tabs </source>
+        <translation>創建圖像標籤</translation>
+    </message>
+    <message>
+        <source>License information</source>
+        <translation>認証資訊</translation>
+    </message>
+    <message>
+        <source>ON</source>
+        <translation>開啟</translation>
+    </message>
+    <message>
+        <source>OFF</source>
+        <translation>關閉</translation>
+    </message>
+    <message>
+        <source>Record Time:</source>
+        <translation>錄製時間：</translation>
+    </message>
+    <message>
+        <source>Video size:</source>
+        <translation>視訊尺寸：</translation>
+    </message>
+    <message>
+        <source>Free disk space:</source>
+        <translation>磁碟空間：</translation>
+    </message>
+    <message>
+        <source>Information</source>
+        <translation>資訊</translation>
+    </message>
+    <message>
+        <source>Window</source>
+        <translation>視窗</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation>全螢幕</translation>
+    </message>
+    <message>
+        <source>Area</source>
+        <translation>區域</translation>
+    </message>
+    <message>
+        <source>Videocodec</source>
+        <translation>影像編碼</translation>
+    </message>
+    <message>
+        <source>Frames</source>
+        <translation>影格率</translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation>格式</translation>
+    </message>
+    <message>
+        <source>Available</source>
+        <translation>可提供</translation>
+    </message>
+    <message>
+        <source>Not available</source>
+        <translation>沒有</translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation>開始</translation>
+    </message>
+    <message>
+        <source>Stop</source>
+        <translation>停止</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation>暫停</translation>
+    </message>
+    <message>
+        <source>Continue</source>
+        <translation>繼續</translation>
+    </message>
+    <message>
+        <source>Play</source>
+        <translation>播放</translation>
+    </message>
+    <message>
+        <source>Folder</source>
+        <translation>資料夾</translation>
+    </message>
+    <message>
+        <source>Do not record mouse cursor</source>
+        <translation>不要錄製滑鼠游標</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
@@ -601,7 +725,7 @@
     </message>
 </context>
 <context>
-    <name>player</name>
+    <name>playerGST</name>
     <message>
         <source>Play</source>
         <translation>播放</translation>
@@ -614,29 +738,5 @@
         <source>Stop</source>
         <translation>停止</translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation>開啟檔案</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>全螢幕</translation>
-    </message>
-    <message>
-        <source>Previous frame</source>
-        <translation>上一個影格</translation>
-    </message>
-    <message>
-        <source>Next frame</source>
-        <translation>上一個影格</translation>
-    </message>
-    <message>
-        <source>Mute</source>
-        <translation>靜音</translation>
-    </message>
-    <message>
-        <source>Move menu</source>
-        <translation>移動選單</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
