@@ -28,7 +28,8 @@
 #include <QFont>
 #include <QDialogButtonBox>
 
-QvkLicenses::QvkLicenses( Ui_formMainWindow *ui_mainwindow ) : ui( new Ui::license )
+//QvkLicenses::QvkLicenses( Ui_formMainWindow *ui_mainwindow ) : ui( new Ui::license )
+QvkLicenses::QvkLicenses( QPushButton *pushButton ) : ui( new Ui::license )
 {
     ui->setupUi( this );
 
@@ -36,8 +37,8 @@ QvkLicenses::QvkLicenses( Ui_formMainWindow *ui_mainwindow ) : ui( new Ui::licen
     icon.addFile( QString::fromUtf8( ":/pictures/logo/logo.png" ), QSize(), QIcon::Normal, QIcon::Off );
     setWindowIcon( icon );
 
-    connect( ui_mainwindow->pushButtonLicense, SIGNAL( clicked( bool ) ), this, SLOT( show() ) );
-    connect(ui->buttonBox, SIGNAL( clicked( QAbstractButton * ) ), this, SLOT( close() ) );
+    connect( pushButton, SIGNAL( clicked( bool ) ), this, SLOT( show() ) );
+    connect( ui->pushButtonClose, SIGNAL( clicked( bool ) ), this, SLOT( close() ) );
 
     ui->label_dummy_1->hide();
     ui->label_dummy_2->hide();
@@ -55,11 +56,9 @@ QvkLicenses::~QvkLicenses(){}
 int QvkLicenses::readLicences( QString path, int row )
 {
     QDirIterator dirIterator( path, QDir::Files, QDirIterator::Subdirectories );
-    while ( dirIterator.hasNext() )
-    {
+    while ( dirIterator.hasNext() ) {
         QString string = dirIterator.next();
-        if ( ( string.contains( ".license" ) == true ) and ( string.contains( "template" ) == false ) )
-        {
+        if ( ( string.contains( ".license" ) == true ) and ( string.contains( "template" ) == false ) ) {
             QSettings settings( dirIterator.filePath(), QSettings::IniFormat );
             settings.beginGroup( "license" );
 
