@@ -38,8 +38,13 @@ QvkMagnifier::QvkMagnifier()
     slot_magnifier200x200();
 
     resize( 2 * distanceX * factor, 2 * distanceY * factor );
-    setWindowFlags( Qt::FramelessWindowHint | Qt::WindowStaysOnTopHint | Qt::ToolTip ); //With tooltip, no entry in Taskbar
-    setAttribute( Qt::WA_TranslucentBackground, true ); // neu
+#ifdef Q_OS_LINUX
+    setWindowFlags( Qt::X11BypassWindowManagerHint | Qt::WindowStaysOnTopHint );
+#endif
+#ifdef Q_OS_WIN
+    setWindowFlags( Qt::FramelessWindowHint | Qt::WindowStaysOnTopHint | Qt::ToolTip );
+#endif
+    setAttribute( Qt::WA_TranslucentBackground, true );
     distanceCopyMagnifier = 30;
 
     timer = new QTimer( this );
@@ -63,14 +68,12 @@ void QvkMagnifier::slot_setMagnifierChangedSize(int value )
 
 void QvkMagnifier::slot_magnifierShow( bool value )
 {
-    if ( value == true )
-    {
+    if ( value == true ) {
         show();
         timer->start();
     }
 
-    if ( value == false )
-    {
+    if ( value == false ) {
         close();
         timer->stop();
     }
@@ -112,8 +115,7 @@ void QvkMagnifier::setMagnifier()
                              this->width()/2,
                              this->height()/2 );
 
-    if ( regionTopLeft.contains( screenCursorPos ) )
-    {
+    if ( regionTopLeft.contains( screenCursorPos ) ) {
         nameRegion = region::topLeft;
         valueRegion = regionTopLeft;
 
@@ -137,8 +139,7 @@ void QvkMagnifier::setMagnifier()
                                screen->size().width() - 2*this->width()/2,
                                this->height()/2 );
 
-    if ( regionTopMiddle.contains( screenCursorPos ) )
-    {
+    if ( regionTopMiddle.contains( screenCursorPos ) ) {
         nameRegion = region::topMiddle;
         valueRegion = regionTopMiddle;
 
@@ -162,8 +163,7 @@ void QvkMagnifier::setMagnifier()
                               this->width()/2,
                               this->height()/2 );
 
-    if ( regionTopRight.contains( screenCursorPos ) )
-    {
+    if ( regionTopRight.contains( screenCursorPos ) ) {
         nameRegion = region::topRight;
         valueRegion = regionTopRight;
 
@@ -188,8 +188,7 @@ void QvkMagnifier::setMagnifier()
                                  //                        (    Top       )   (             Bottom                      )
                                  screen->size().height() - this->height()/2 - ( this->height() + distanceY + distanceCopyMagnifier ) );
 
-    if ( regionRightMiddle.contains( screenCursorPos ) )
-    {
+    if ( regionRightMiddle.contains( screenCursorPos ) ) {
         nameRegion = region::rightMiddle;
         valueRegion = regionRightMiddle;
 
@@ -207,8 +206,7 @@ void QvkMagnifier::setMagnifier()
                                  this->width()/2,
                                  this->height() + 2*distanceY + distanceCopyMagnifier );
 
-    if ( regionBottomRight.contains( screenCursorPos ) )
-    {
+    if ( regionBottomRight.contains( screenCursorPos ) ) {
         nameRegion = region::bottomRight;
         valueRegion = regionBottomRight;
 
@@ -231,8 +229,7 @@ void QvkMagnifier::setMagnifier()
                                   screen->size().width() - 2*this->width()/2,
                                   this->height() + 2*distanceY + distanceCopyMagnifier );
 
-    if ( regionBottomMiddle.contains( screenCursorPos ) )
-    {
+    if ( regionBottomMiddle.contains( screenCursorPos ) ) {
         nameRegion = region::bottomMiddle;
         valueRegion = regionBottomMiddle;
 
@@ -255,8 +252,7 @@ void QvkMagnifier::setMagnifier()
                                 this->width()/2,
                                 this->height() + 2*distanceY + distanceCopyMagnifier );
 
-    if ( regionBottomLeft.contains( screenCursorPos ) )
-    {
+    if ( regionBottomLeft.contains( screenCursorPos ) ) {
         nameRegion = region::bottomLeft;
         valueRegion = regionBottomLeft;
 
@@ -280,8 +276,7 @@ void QvkMagnifier::setMagnifier()
                                 //                        (    Top       )   (             Bottom                      )
                                 screen->size().height() - this->height()/2 - ( this->height() + distanceY + distanceCopyMagnifier ) );
 
-    if ( regionLeftMiddle.contains( screenCursorPos ) )
-    {
+    if ( regionLeftMiddle.contains( screenCursorPos ) ) {
         nameRegion = region::leftMiddle;
         valueRegion = regionLeftMiddle;
 
@@ -302,8 +297,7 @@ void QvkMagnifier::setMagnifier()
                             screen->size().width() - 2*this->width()/2,
                             screen->size().height() - this->height()/2 - ( this->height() + distanceY + distanceCopyMagnifier ) );
 
-    if ( regionMiddle.contains( screenCursorPos ) )
-    {
+    if ( regionMiddle.contains( screenCursorPos ) ) {
         nameRegion = region::middle;
         valueRegion = regionMiddle;
 
@@ -343,8 +337,6 @@ void QvkMagnifier::slot_mytimer()
     screenIndex = screenList.indexOf( screen );
     if( debug == true ) { qDebug() << "slot_mytimer screenIndex:" << screenIndex; }
 
-    setMagnifier();
-
     // Begin grab
     int valueX = 0;
     int valueY = 0;
@@ -467,7 +459,44 @@ void QvkMagnifier::slot_mytimer()
                                      2*distanceX,
                                      2*distanceY);
 
-        repaint();
+        if ( pixmap.isNull() == true ) {
+                    return;
+        }
+
+        QPixmap painterPixmap( pixmap.width() * factor, pixmap.height() * factor );
+        painterPixmap.fill( Qt::transparent );
+
+        QPainter painter;
+        painter.begin( &painterPixmap );
+        painter.setRenderHints( QPainter::Antialiasing, true );
+        painter.setRenderHint( QPainter::SmoothPixmapTransform, true );
+
+        if ( ( isToolButtonElipse == true ) or ( isToolButtonCircle == true ) ) {
+                    QPainterPath path;
+                    path.addEllipse( 0, 0, width(), height() );
+                    painter.setClipPath( path );
+        }
+
+        QPixmap pix = pixmap.scaled( painterPixmap.width(), painterPixmap.height(), Qt::IgnoreAspectRatio, Qt::SmoothTransformation );
+        painter.drawPixmap( QPoint( 0, 0 ), pix );
+
+        QPen pen;
+        pen.setWidth( 7 );
+        pen.setColor( Qt::lightGray );
+        painter.setPen( pen );
+        if ( ( isToolButtonElipse == true ) or ( isToolButtonCircle == true ) ) {
+                    painter.drawEllipse( 0, 0, width(), height() );
+        } else {
+                    painter.drawRect( 0, 0, width(), height() );
+        }
+        painter.end();
+
+        setPixmap( painterPixmap );
+        setMagnifier();
+
+#ifdef Q_OS_LINUX
+        setMask( painterPixmap.mask() );
+#endif
 
         if ( debug == true ) { qDebug().noquote() << "Grab" << enumToString( nameRegion ) << valueRegion
                                                   << "globalCursorPos:" << globalCursorPos
@@ -476,57 +505,6 @@ void QvkMagnifier::slot_mytimer()
 }
 
 
-void QvkMagnifier::paintEvent( QPaintEvent *event )
-{
-    Q_UNUSED(event);
-    if ( pixmap.isNull() == true ) {
-        return;
-    }
-
-    QPixmap painterPixmap( pixmap.width() * factor, pixmap.height() * factor );
-    painterPixmap.fill( Qt::transparent );
-
-    QPainter painter;
-    painter.begin( &painterPixmap );
-    painter.setRenderHints( QPainter::Antialiasing, true );
-    painter.setRenderHint( QPainter::SmoothPixmapTransform, true );
-
-    if ( ( isToolButtonElipse == true ) or ( isToolButtonCircle == true ) ) {
-        QPainterPath path;
-        path.addEllipse( 0, 0, width(), height() );
-        painter.setClipPath( path );
-    }
-
-    QPixmap pix = pixmap.scaled( painterPixmap.width(), painterPixmap.height(), Qt::IgnoreAspectRatio, Qt::SmoothTransformation );
-    painter.drawPixmap( QPoint( 0, 0 ), pix );
-
-    QPen pen;
-    pen.setWidth( 7 );
-    pen.setColor( Qt::lightGray );
-    painter.setPen( pen );
-    if ( ( isToolButtonElipse == true ) or ( isToolButtonCircle == true ) ) {
-        painter.drawEllipse( 0, 0, width(), height() );
-    } else {
-        painter.drawRect( 0, 0, width(), height() );
-    }
-    painter.end();
-
-    QPainter painter_1;
-    painter_1.begin( this );
-    painter_1.setRenderHint( QPainter::Antialiasing, true );
-    painter_1.setRenderHint( QPainter::SmoothPixmapTransform, true );
-    painter_1.drawPixmap( QPoint( 0, 0 ), painterPixmap );
-    painter_1.end();
-
-    // This can delete if vokoscreen run only with a compositer.
-    // This is also not required under Windows, Windows has a compositer.
-#ifdef Q_OS_LINUX
-    setMask( painterPixmap.mask() );
-#endif
-
-}
-
-
 QString QvkMagnifier::enumToString( region reg )
 {
     QString string;
