@@ -123,16 +123,17 @@ int main(int argc, char *argv[])
     QString pathProfile = dirPathProfile.absolutePath();
     QString programPath = QDir::currentPath();
 
+    // Die GStreamer plugins werden über die GST_PLUGIN_PATH_1_0 variable gefunden
     QString pluginPath;
     pluginPath.append( programPath );
-    pluginPath.append( separator );
-    pluginPath.append( pathProfile );
     qputenv( "GST_PLUGIN_PATH_1_0", pluginPath.toUtf8() );
 
+    // Der openh264 Codec wird über die PATH variable gefunden
     QString pathPath;
     pathPath.append( programPath );
     pathPath.append( separator );
-    pathPath.append( pathProfile );
+    QFileInfo h264Profile( vkSettings.getOpenh264ProfilePathWithFilename() );
+    pathPath.append( h264Profile.absolutePath() );
     qputenv( "PATH", pathPath.toUtf8() );
 
     QString pathRegistry;
@@ -164,17 +165,8 @@ int main(int argc, char *argv[])
     }
     // Gstreamer debug end
 
-
     gst_init (&argc, &argv);
 
-    QTranslator * qtTranslator = new QTranslator();
-    qtTranslator->load( "qt_" + QLocale::system().name(), QLibraryInfo::location( QLibraryInfo::TranslationsPath ) );
-    app.installTranslator( qtTranslator );
-
-    QTranslator translator;
-    translator.load( QLocale::system().name(), ":/language" );
-    app.installTranslator( &translator );
-
 #ifdef Q_OS_LINUX
     if ( QvkWaylandRoutines::is_Wayland_Display_Available() == false )
     {
