@@ -1,4 +1,4 @@
-/* vokoscreenNG - A desktop recorder
+﻿/* vokoscreenNG - A desktop recorder
  * Copyright (C) 2017-2022 Volker Kohaupt
  * 
  * Author:
@@ -31,13 +31,7 @@
 #include "QvkHelp.h"
 #include "QvkSystray.h"
 #include "QvkMagnifierController.h"
-#if (QT_VERSION <= QT_VERSION_CHECK(6, 0, 0))
-    // Qt5
-    #include "QvkPlayer.h"
-#else
-    // Qt6
-#endif
-
+#include "QvkPlayerController.h"
 #include "QvkLimitDiskFreeSpace.h"
 #include "QvkSpezialSlider.h"
 #include "QvkSystrayAlternative.h"
@@ -46,6 +40,8 @@
 #include "QvkHalo.h"
 #include "QvkGlobalShortcut.h"
 #include "QvkLogController.h"
+#include "QvkContainerController.h"
+#include "QvkLicenses.h"
 
 #ifdef Q_OS_WIN
   #include "QvkCiscoOpenh264Controller.h"
@@ -55,6 +51,7 @@
 #include <QFileSystemWatcher>
 #include <QSoundEffect>
 #include <QShowEvent>
+#include <QTranslator>
 
 #include <gst/gst.h>
 
@@ -79,8 +76,12 @@ public:
     QvkMagnifierController *vkMagnifierController;
     QvkGlobalShortcut *vkGlobalShortcut;
     QvkLogController *vklogController;
+    QvkLicenses *vkLicenses;
+    QvkHelp *vkHelp;
+    QvkCameraController *vkCameraController;
     bool wantRecording = true;
     bool isFlatpak = false;
+    void changeLanguageInSourcecode();
 
 
 private:
@@ -118,8 +119,6 @@ private:
 
     QStringList videoFormatsList;
 
-    void VK_Supported_Formats_And_Codecs();
-    void VK_Check_is_Format_available();
     void VK_set_available_Formats_in_Combox();
     QString VK_get_AudioSystem();
     QStringList VK_getSelectedAudioDevice();
@@ -132,21 +131,17 @@ private:
     QString get_height_From_Screen();
 
     void VK_gst_Elements_available();
+    QvkContainerController *vkContainerController;
 
     QTimer *timerStartTimer;
     QTimer *timerStopRecordingAfter = new QTimer( this );
 
     void vk_setCornerWidget( QTabWidget *tabWidget );
 
-#if (QT_VERSION <= QT_VERSION_CHECK(6, 0, 0))
-    // Qt5
-    QvkPlayer *vkPlayer;
-#else
-    // Qt6
-#endif
+    QvkPlayerController *vkPlayerController; // This is for the new GStreamer player
+
     QvkHalo *vkHalo;
 
-    QvkCameraController *vkCameraController;
     QvkSystrayAlternative *vkSystrayAlternative;
 
     QvkLimitDiskFreeSpace *vkLimitDiskFreeSpace;
@@ -164,11 +159,17 @@ private:
 
     bool gst_appsrc = false;
 
+    QTranslator translator;
+    QTranslator qtTranslator;
+
 #ifdef Q_OS_WIN
     QvkCiscoOpenh264Controller *vkCiscoOpenh264Controller;
     QTemporaryDir wasapiTemporaryDir;
 #endif
 
+    QvkSpezialCheckbox *vkSpezialCheckboxDarkMode;
+    QPalette oldPaletteDarkMode;
+
 
 private slots:
     void slot_textToGuiLog( QString value );
@@ -190,8 +191,6 @@ private slots:
     void slot_startCounter( bool value );
     void slot_comboBoxScreencastScreenCountdown( bool );
 
-    void slot_set_available_VideoCodecs_in_Combox( QString suffix );
-    void slot_set_available_AudioCodecs_in_Combox( QString suffix );
     void slot_videoCodecChanged( QString codec );
     void slot_framesReset();
     void slot_x264Reset();
@@ -211,8 +210,6 @@ private slots:
 
     void slot_setMaxFPS( int );
 
-    void slot_gst_formatVideoAudoicodec_available();
-
     void slot_cancel( bool value );
 
     void slot_haveAudioDeviceSelected( bool bo );
@@ -221,6 +218,12 @@ private slots:
 
     void slot_disableShowclickHalo( bool bo );
 
+    void slot_currentTextChangedToGIF( QString value);
+
+    void slot_languageChanged(int);
+
+    void slot_darkMode( bool bo );
+
 
 signals:
     void signal_close();
