@@ -59,6 +59,7 @@ QvkRegionChoise::QvkRegionChoise( Ui_formMainWindow *ui_formMainWindow ):handleP
     icon.addFile( QString::fromUtf8( ":/pictures/logo/logo.png" ), QSize(), QIcon::Normal, QIcon::Off );
     setWindowIcon( icon );
 
+    // Beim Mate Desktop wird die Bereichsauswahl beim setzen von Qt::ToolTip nicht aktualisiert.
     QString currentDesktop = qgetenv( "XDG_CURRENT_DESKTOP" );
     if( currentDesktop.toLower() == QString( "Mate" ).toLower() ) {
         setWindowFlags( Qt::FramelessWindowHint | Qt::WindowStaysOnTopHint );
@@ -76,8 +77,7 @@ QvkRegionChoise::QvkRegionChoise( Ui_formMainWindow *ui_formMainWindow ):handleP
 void QvkRegionChoise::slot_init()
 {
 #ifdef Q_OS_LINUX
-    if ( ui->comboBoxScreencastScreenArea->currentIndex() > -1 )
-    {
+    if ( ui->comboBoxScreencastScreenArea->currentIndex() > -1 ) {
         int index = ui->comboBoxScreencastScreenArea->currentIndex();
         QList<QScreen *> screenList = QGuiApplication::screens();
         screen = screenList.at( index );
@@ -91,15 +91,13 @@ void QvkRegionChoise::slot_init()
 
 #ifdef Q_OS_WIN
     // Für das anzeigen der Bereichsanzeige auf dem Bildschirm wird der Index aus einer unsortierten Liste benötigt.
-    if ( ui->comboBoxScreencastScreenArea->currentIndex() > -1 )
-    {
+    if ( ui->comboBoxScreencastScreenArea->currentIndex() > -1 ) {
         int index = 0;
         QString nameDisplay = ui->comboBoxScreencastScreenArea->currentText().section( ":", 0, 0 ).trimmed();
         QList<QScreen *> screenList = QGuiApplication::screens(); // unsortiert
         for ( int i=0; i < screenList.count(); i++ ) {
             QString nameList = screenList.at(i)->name().remove( "." ).remove( "\\" ) ;
-            if ( nameDisplay == nameList )
-            {
+            if ( nameDisplay == nameList ) {
                 index = i;
             }
         }
@@ -151,11 +149,9 @@ void QvkRegionChoise::vk_setGeometry( int x, int y, int with, int height  )
 void QvkRegionChoise::paintEvent( QPaintEvent *event )
 {
     (void)event;
-
     QPixmap pixmap( screenWidth, screenHeight );
 
-    if ( recordemode == false )
-    {
+    if ( recordemode == false ) {
         pixmap.fill( Qt::transparent );
         QPainter painterPixmap;
         painterPixmap.begin( &pixmap );
@@ -185,9 +181,7 @@ void QvkRegionChoise::paintEvent( QPaintEvent *event )
         case Middle      : HandleTopLeftSize( painterPixmap );     break;
         }
         painterPixmap.end();
-    }
-    else
-    {
+    } else {
         pixmap.fill( Qt::transparent );
         QPainter painterPixmap;
         painterPixmap.begin( &pixmap );
@@ -255,8 +249,7 @@ void QvkRegionChoise::paintEvent( QPaintEvent *event )
 
 void QvkRegionChoise::mousePressEvent(QMouseEvent *event)
 {
-    if( event->button() != Qt::LeftButton)
-    {
+    if( event->button() != Qt::LeftButton) {
         return;
     }
 
@@ -292,8 +285,7 @@ void QvkRegionChoise::mousePressEvent(QMouseEvent *event)
 
 void QvkRegionChoise::mouseReleaseEvent( QMouseEvent * event )
 {
-  if( event->button() != Qt::LeftButton)
-  {
+  if( event->button() != Qt::LeftButton) {
       return;
   }
 
@@ -315,13 +307,11 @@ void QvkRegionChoise::leaveEvent(QEvent *event)
 
 void QvkRegionChoise::keyPressEvent( QKeyEvent * event )
 {
-    if ( recordemode == true )
-    {
+    if ( recordemode == true ) {
         return;
     }
 
-    if ( handleKeyPressed == TopLeft )
-    {
+    if ( handleKeyPressed == TopLeft ) {
         switch ( event->key() )
         {
             case Qt::Key_Up   :  {
@@ -375,8 +365,7 @@ void QvkRegionChoise::keyPressEvent( QKeyEvent * event )
         }
     }
 
-    if ( handleKeyPressed == TopMiddle )
-    {
+    if ( handleKeyPressed == TopMiddle ) {
         switch ( event->key() )
         {
             case Qt::Key_Up   : {
@@ -406,8 +395,7 @@ void QvkRegionChoise::keyPressEvent( QKeyEvent * event )
         }
     }
 
-    if ( handleKeyPressed == TopRight )
-    {
+    if ( handleKeyPressed == TopRight ) {
         switch ( event->key() )
         {
             case Qt::Key_Up   : {
@@ -457,8 +445,7 @@ void QvkRegionChoise::keyPressEvent( QKeyEvent * event )
         }
     }
 
-    if ( handleKeyPressed == RightMiddle )
-    {
+    if ( handleKeyPressed == RightMiddle ) {
         switch ( event->key() )
         {
             case Qt::Key_Left : {
@@ -484,8 +471,7 @@ void QvkRegionChoise::keyPressEvent( QKeyEvent * event )
         }
     }
 
-    if ( handleKeyPressed == BottomRight )
-    {
+    if ( handleKeyPressed == BottomRight ) {
         switch ( event->key() )
         {
             case Qt::Key_Up   : {
@@ -531,8 +517,7 @@ void QvkRegionChoise::keyPressEvent( QKeyEvent * event )
         }
     }
 
-    if ( handleKeyPressed == BottomMiddle )
-    {
+    if ( handleKeyPressed == BottomMiddle ) {
         switch ( event->key() )
         {
             case Qt::Key_Up   : {
@@ -558,8 +543,7 @@ void QvkRegionChoise::keyPressEvent( QKeyEvent * event )
         }
      }
 
-    if ( handleKeyPressed == BottomLeft )
-    {
+    if ( handleKeyPressed == BottomLeft ) {
         switch ( event->key() )
         {
             case Qt::Key_Up   :  {
@@ -609,8 +593,7 @@ void QvkRegionChoise::keyPressEvent( QKeyEvent * event )
         }
     }
 
-    if ( handleKeyPressed == LeftMiddle )
-    {
+    if ( handleKeyPressed == LeftMiddle ) {
         switch ( event->key() )
         {
             case Qt::Key_Left  : {
@@ -640,8 +623,7 @@ void QvkRegionChoise::keyPressEvent( QKeyEvent * event )
         }
     }
 
-    if ( handleKeyPressed == Middle )
-    {
+    if ( handleKeyPressed == Middle ) {
         switch ( event->key() )
         {
             case Qt::Key_Left  : {
@@ -694,8 +676,9 @@ void QvkRegionChoise::keyPressEvent( QKeyEvent * event )
 
 void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
 {
-    if ( recordemode == true )
+    if ( recordemode == true ) {
         return;
+    }
 
     switch ( handlePressed )
     {
@@ -707,27 +690,23 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
                            frame_height = old_Mouse_Y - event->y() + old_Frame_Height;
 
                            // Limit min
-                           if ( frame_Width < frame_min_width )
-                           {
+                           if ( frame_Width < frame_min_width ) {
                              frame_X = old_Frame_X2 - frame_min_width;
                              frame_Width = frame_min_width;
                            }
 
-                           if ( frame_height < frame_min_height )
-                           {
+                           if ( frame_height < frame_min_height ) {
                              frame_Y = old_Frame_Y2 - frame_min_height;
                              frame_height = frame_min_height;
                            }
 
                            // Limit max
-                           if ( frame_Y <= 0 - framePenHalf )
-                           {
+                           if ( frame_Y <= 0 - framePenHalf ) {
                              frame_Y = 0 - framePenHalf;
                              frame_height = old_Frame_Y2 + framePenHalf;
                            }
 
-                           if ( frame_X <= 0 - framePenHalf )
-                           {
+                           if ( frame_X <= 0 - framePenHalf ) {
                               frame_X = 0 - framePenHalf;
                               frame_Width = old_Frame_X2 + framePenHalf;
                            }
@@ -739,15 +718,13 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
                            frame_height = old_Mouse_Y - event->y() + old_Frame_Height;
 
                            // Limit min
-                           if ( frame_height < frame_min_height )
-                           {
+                           if ( frame_height < frame_min_height ) {
                              frame_Y = old_Frame_Y2 - frame_min_height;
                              frame_height = frame_min_height;
                            }
 
                            // Limit max
-                           if ( frame_Y <= 0 - framePenHalf )
-                           {
+                           if ( frame_Y <= 0 - framePenHalf ) {
                              frame_Y = 0 - framePenHalf;
                              frame_height = old_Frame_Y2 + framePenHalf;
                            }
@@ -760,26 +737,22 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
                            frame_height = old_Mouse_Y - event->y() + old_Frame_Height;;
 
                            // Limit min
-                           if ( frame_Width < frame_min_width )
-                           {
+                           if ( frame_Width < frame_min_width ) {
                              frame_Width = frame_min_width;
                            }
 
-                           if ( frame_height < frame_min_height )
-                           {
+                           if ( frame_height < frame_min_height ) {
                              frame_Y = old_Frame_Y2 - frame_min_height;
                              frame_height = frame_min_height;
                            }
 
                            // Limit max
-                           if ( frame_Y <= 0 - framePenHalf )
-                           {
+                           if ( frame_Y <= 0 - framePenHalf ) {
                              frame_Y = 0 - framePenHalf;
                              frame_height = old_Frame_Y2 + framePenHalf;
                            }
 
-                           if( ( frame_X + frame_Width - framePenHalf ) > screenWidth )
-                           {
+                           if( ( frame_X + frame_Width - framePenHalf ) > screenWidth ) {
                              frame_Width = screenWidth + framePenHalf - frame_X;
                            }
 
@@ -789,14 +762,12 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
                            frame_Width = event->x() - old_Mouse_X + old_Frame_Width;
 
                            // Limit min
-                           if ( frame_Width < frame_min_width )
-                           {
+                           if ( frame_Width < frame_min_width ) {
                              frame_Width = frame_min_width;
                            }
 
                            // Limit max
-                           if( ( frame_X + frame_Width - framePenHalf ) > screenWidth )
-                           {
+                           if( ( frame_X + frame_Width - framePenHalf ) > screenWidth ) {
                              frame_Width = screenWidth + framePenHalf - frame_X;
                            }
 
@@ -807,24 +778,20 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
                            frame_height = event->y() - old_Mouse_Y + old_Frame_Height;
 
                            // Limit min
-                           if ( frame_Width < frame_min_width )
-                           {
+                           if ( frame_Width < frame_min_width ) {
                              frame_Width = frame_min_width;
                            }
 
-                           if ( frame_height < frame_min_height )
-                           {
+                           if ( frame_height < frame_min_height ) {
                              frame_height = frame_min_height;
                            }
 
                            //Limit max
-                           if( ( frame_X + frame_Width - framePenHalf ) > screenWidth )
-                           {
+                           if( ( frame_X + frame_Width - framePenHalf ) > screenWidth ) {
                              frame_Width = screenWidth + framePenHalf - frame_X;
                            }
 
-                           if( ( frame_Y + frame_height - framePenHalf ) > screenHeight )
-                           {
+                           if( ( frame_Y + frame_height - framePenHalf ) > screenHeight ) {
                              frame_height = screenHeight + framePenHalf - frame_Y;
                            }
 
@@ -834,14 +801,12 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
                            frame_height = event->y() - old_Mouse_Y + old_Frame_Height;
 
                            // Limit min
-                           if ( frame_height < frame_min_height )
-                           {
+                           if ( frame_height < frame_min_height ) {
                              frame_height = frame_min_height;
                            }
 
                            //Limit max
-                           if( ( frame_Y + frame_height - framePenHalf ) > screenHeight )
-                           {
+                           if( ( frame_Y + frame_height - framePenHalf ) > screenHeight ) {
                              frame_height = screenHeight + framePenHalf - frame_Y;
                            }
 
@@ -854,26 +819,22 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
                            frame_Width = old_Mouse_X - event->x() + old_Frame_Width;
 
                            // Limit min
-                           if ( frame_Width < frame_min_width )
-                           {
+                           if ( frame_Width < frame_min_width ) {
                              frame_X = old_Frame_X2 - frame_min_width;
                              frame_Width = frame_min_width;
                            }
 
-                           if ( frame_height < frame_min_height )
-                           {
+                           if ( frame_height < frame_min_height ) {
                              frame_height = frame_min_height;
                            }
 
                            // Limit max
-                           if ( frame_X <= 0 - framePenHalf )
-                           {
+                           if ( frame_X <= 0 - framePenHalf ) {
                               frame_X = 0 - framePenHalf;
                               frame_Width = old_Frame_X2 + framePenHalf;
                            }
 
-                           if( ( frame_Y + frame_height - framePenHalf ) > screenHeight )
-                           {
+                           if( ( frame_Y + frame_height - framePenHalf ) > screenHeight ) {
                              frame_height = screenHeight + framePenHalf - frame_Y;
                            }
 
@@ -884,15 +845,13 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
                            frame_Width = old_Mouse_X - event->x() + old_Frame_Width;
 
                            // Limit min
-                           if ( frame_Width < frame_min_width )
-                           {
+                           if ( frame_Width < frame_min_width ) {
                              frame_X = old_Frame_X2 - frame_min_width;
                              frame_Width = frame_min_width;
                            }
 
                            // Limit max
-                           if ( frame_X <= 0 - framePenHalf )
-                           {
+                           if ( frame_X <= 0 - framePenHalf ) {
                               frame_X = 0 - framePenHalf;
                               frame_Width = old_Frame_X2 + framePenHalf;
                            }
@@ -906,26 +865,22 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
                            frame_Y = event->y() - frame_height/2 + framePenHalf + deltaY;
 
                            // Limit Top
-                           if ( frame_Y <= 0 - framePenHalf )
-                           {
+                           if ( frame_Y <= 0 - framePenHalf ) {
                              frame_Y = 0 - framePenHalf;
                            }
 
                            // Limit Left
-                           if ( frame_X <= 0 - framePenHalf )
-                           {
+                           if ( frame_X <= 0 - framePenHalf ) {
                              frame_X = 0 - framePenHalf;
                            }
 
                            // Limit Right
-                           if( ( frame_X + frame_Width - framePenHalf ) > screenWidth )
-                           {
+                           if( ( frame_X + frame_Width - framePenHalf ) > screenWidth ) {
                                frame_X = screenWidth - frame_Width + framePenHalf;
                            }
 
                            // Limit Bottom
-                           if( ( frame_Y + frame_height - framePenHalf ) > screenHeight )
-                           {
+                           if( ( frame_Y + frame_height - framePenHalf ) > screenHeight ) {
                                frame_Y = screenHeight - frame_height + framePenHalf;
                            }
 
@@ -936,12 +891,12 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
     repaint();
     update();
 
-    if ( handlePressed != NoHandle )
+    if ( handlePressed != NoHandle ) {
         return;
+    }
 
     QRect regionTopLeft( frame_X - radius - 1, frame_Y - radius - 1, diameter + 2, diameter + 2 );
-    if ( regionTopLeft.contains( event->pos() ) )
-    {
+    if ( regionTopLeft.contains( event->pos() ) ) {
         QPixmap pixmap( ":/pictures/cursor/size_fdiag.png" );
         QCursor cursor( pixmap );
         setCursor( cursor );
@@ -950,8 +905,7 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
     }
 
     QRect regionTopMiddle( frame_X + frame_Width/2 - radius - 1, frame_Y - radius - 1, diameter + 2, diameter + 2 );
-    if ( regionTopMiddle.contains( event->pos() )  )
-    {
+    if ( regionTopMiddle.contains( event->pos() )  ) {
         QPixmap pixmap( ":/pictures/cursor/size_ver.png" );
         QCursor cursor( pixmap );
         setCursor( cursor );
@@ -960,8 +914,7 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
     }
 
     QRect regionTopRight( frame_X + frame_Width - radius - 1, frame_Y - radius - 1, diameter + 2, diameter + 2 );
-    if ( regionTopRight.contains( event->pos() )  )
-    {
+    if ( regionTopRight.contains( event->pos() ) ) {
         QPixmap pixmap( ":/pictures/cursor/size_bdiag.png" );
         QCursor cursor( pixmap );
         setCursor( cursor );
@@ -970,8 +923,7 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
     }
 
     QRect regionRightMiddle( frame_X + frame_Width - radius - 1, frame_Y + frame_height/2 - radius - 1, diameter + 2, diameter + 2 );
-    if ( regionRightMiddle.contains( event->pos() )  )
-    {
+    if ( regionRightMiddle.contains( event->pos() ) ) {
         QPixmap pixmap( ":/pictures/cursor/size_hor.png" );
         QCursor cursor( pixmap );
         setCursor( cursor );
@@ -980,8 +932,7 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
     }
 
     QRect regionMiddle( frame_X + frame_Width/2 - radius - penHalf, frame_Y + frame_height/2 - radius - penHalf, 2 * radius + penWidth, 2 * radius + penWidth);
-    if ( regionMiddle.contains( event->pos() )  )
-    {
+    if ( regionMiddle.contains( event->pos() ) ) {
         QPixmap pixmap( ":/pictures/cursor/size_all.png" );
         QCursor cursor( pixmap );
         setCursor( cursor );
@@ -995,8 +946,7 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
                                buttonArrow.getWithHalf()*2,
                                buttonArrow.getWithHalf()*2
                               );
-    if( regionBottomRight.contains( event->pos()) )
-    {
+    if( regionBottomRight.contains( event->pos() ) ) {
         QPixmap pixmap( ":/pictures/cursor/size_fdiag.png" );
         QCursor cursor( pixmap );
         setCursor( cursor );
@@ -1009,8 +959,7 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
                                 buttonArrow.getWithHalf()*2,
                                 buttonArrow.getWithHalf()*2
                                );
-    if( regionBottomMiddle.contains( event->pos()) )
-    {
+    if( regionBottomMiddle.contains( event->pos() ) ) {
         QPixmap pixmap( ":/pictures/cursor/size_ver.png" );
         QCursor cursor( pixmap );
         setCursor( cursor );
@@ -1023,8 +972,7 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
                               buttonArrow.getWithHalf()*2,
                               buttonArrow.getWithHalf()*2
                             );
-    if( regionBottomLeft.contains( event->pos()) )
-    {
+    if( regionBottomLeft.contains( event->pos() ) ) {
         QPixmap pixmap( ":/pictures/cursor/size_bdiag.png" );
         QCursor cursor( pixmap );
         setCursor( cursor );
@@ -1037,8 +985,7 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
                               buttonArrow.getWithHalf()*2,
                               buttonArrow.getWithHalf()*2
                             );
-    if( regionLeftMiddle.contains( event->pos()) )
-    {
+    if( regionLeftMiddle.contains( event->pos() ) ) {
         QPixmap pixmap( ":/pictures/cursor/size_hor.png" );
         QCursor cursor( pixmap );
         setCursor( cursor );
@@ -1128,22 +1075,16 @@ void QvkRegionChoise::HandleTopLeft( QPainter &painter )
     QvkRegionButtonArrow buttonArrow;
     QColor color;
 
-    if ( handlePressed == TopLeft )
-    {
+    if ( handlePressed == TopLeft ) {
         color = HandleColorByMousePressed;
-    }
-    else
-    {
+    } else {
         color = HandleColorBackground;
     }
 
     QColor colorSelected;
-    if ( HandleSelected == TopLeft )
-    {
+    if ( HandleSelected == TopLeft ) {
         colorSelected = colorSelectedArrow;
-    }
-    else
-    {
+    } else {
         colorSelected = Qt::black;
     }
 
@@ -1185,22 +1126,16 @@ void QvkRegionChoise::HandleTopMiddle( QPainter &painter)
     QvkRegionButtonArrow buttonArrow;
     QColor color;
 
-    if ( handlePressed == TopMiddle )
-    {
+    if ( handlePressed == TopMiddle ) {
         color = HandleColorByMousePressed;
-    }
-    else
-    {
+    } else {
         color = HandleColorBackground;
     }
 
     QColor colorSelected;
-    if ( HandleSelected == TopMiddle )
-    {
+    if ( HandleSelected == TopMiddle ) {
         colorSelected = colorSelectedArrow;
-    }
-    else
-    {
+    } else {
         colorSelected = Qt::black;
     }
 
@@ -1240,22 +1175,16 @@ void QvkRegionChoise::HandleTopRight(QPainter &painter)
     QvkRegionButtonArrow buttonArrow;
     QColor color;
 
-    if ( handlePressed == TopRight )
-    {
+    if ( handlePressed == TopRight ) {
         color = HandleColorByMousePressed;
-    }
-    else
-    {
+    } else {
         color = HandleColorBackground;
     }
 
     QColor colorSelected;
-    if ( HandleSelected == TopRight )
-    {
+    if ( HandleSelected == TopRight ) {
         colorSelected = colorSelectedArrow;
-    }
-    else
-    {
+    } else {
         colorSelected = Qt::black;
     }
 
@@ -1297,22 +1226,16 @@ void QvkRegionChoise::HandleRightMiddle( QPainter &painter )
     QvkRegionButtonArrow buttonArrow;
     QColor color;
 
-    if ( handlePressed == RightMiddle )
-    {
+    if ( handlePressed == RightMiddle ) {
         color = HandleColorByMousePressed;
-    }
-    else
-    {
+    } else {
         color = HandleColorBackground;
     }
 
     QColor colorSelected;
-    if ( HandleSelected == RightMiddle )
-    {
+    if ( HandleSelected == RightMiddle ) {
         colorSelected = colorSelectedArrow;
-    }
-    else
-    {
+    } else {
         colorSelected = Qt::black;
     }
 
@@ -1352,22 +1275,16 @@ void QvkRegionChoise::HandleBottomRight( QPainter &painter )
     QvkRegionButtonArrow buttonArrow;
     QColor color;
 
-    if ( handlePressed == BottomRight )
-    {
+    if ( handlePressed == BottomRight ) {
         color = HandleColorByMousePressed;
-    }
-    else
-    {
+    } else {
         color = HandleColorBackground;
     }
 
     QColor colorSelected;
-    if ( HandleSelected == BottomRight )
-    {
+    if ( HandleSelected == BottomRight ) {
         colorSelected = colorSelectedArrow;
-    }
-    else
-    {
+    } else {
         colorSelected = Qt::black;
     }
 
@@ -1411,22 +1328,16 @@ void QvkRegionChoise::HandleBottomMiddle( QPainter &painter )
     QvkRegionButtonArrow buttonArrow;
     QColor color;
 
-    if ( handlePressed == BottomMiddle )
-    {
+    if ( handlePressed == BottomMiddle ) {
         color = HandleColorByMousePressed;
-    }
-    else
-    {
+    } else {
         color = HandleColorBackground;
     }
 
     QColor colorSelected;
-    if ( HandleSelected == BottomMiddle )
-    {
+    if ( HandleSelected == BottomMiddle ) {
         colorSelected = colorSelectedArrow;
-    }
-    else
-    {
+    } else {
         colorSelected = Qt::black;
     }
 
@@ -1466,22 +1377,16 @@ void QvkRegionChoise::HandleBottomLeft( QPainter &painter )
     QvkRegionButtonArrow buttonArrow;
     QColor color;
 
-    if ( handlePressed == BottomLeft )
-    {
+    if ( handlePressed == BottomLeft ) {
         color = HandleColorByMousePressed;
-    }
-    else
-    {
+    } else {
         color = HandleColorBackground;
     }
 
     QColor colorSelected;
-    if ( HandleSelected == BottomLeft )
-    {
+    if ( HandleSelected == BottomLeft ) {
         colorSelected = colorSelectedArrow;
-    }
-    else
-    {
+    } else {
         colorSelected = Qt::black;
     }
 
@@ -1523,22 +1428,16 @@ void QvkRegionChoise::HandleLeftMiddle( QPainter &painter )
     QvkRegionButtonArrow buttonArrow;
     QColor color;
 
-    if ( handlePressed == LeftMiddle )
-    {
+    if ( handlePressed == LeftMiddle ) {
         color = HandleColorByMousePressed;
-    }
-    else
-    {
+    } else {
         color = HandleColorBackground;
     }
 
     QColor colorSelected;
-    if ( HandleSelected == LeftMiddle )
-    {
+    if ( HandleSelected == LeftMiddle ) {
         colorSelected = colorSelectedArrow;
-    }
-    else
-    {
+    } else {
         colorSelected = Qt::black;
     }
 
@@ -1579,22 +1478,16 @@ void QvkRegionChoise::HandleMiddle( QPainter &painter )
     QvkRegionButtonArrow buttonArrow;
     QColor color;
 
-    if ( handlePressed == Middle )
-    {
+    if ( handlePressed == Middle ) {
         color = HandleColorByMousePressed;
-    }
-    else
-    {
+    } else {
         color = HandleColorBackground;
     }
 
     QColor colorSelected;
-    if ( HandleSelected == Middle )
-    {
+    if ( HandleSelected == Middle ) {
         colorSelected = colorSelectedArrow;
-    }
-    else
-    {
+    } else {
         colorSelected = Qt::black;
     }
 
@@ -1622,14 +1515,11 @@ void QvkRegionChoise::HandleMiddle( QPainter &painter )
 
 void QvkRegionChoise::recordMode( bool value )
 {
-    if ( value == true )
-    {
+    if ( value == true ) {
         recordemode = true;
         repaint();
         update();
-    }
-    else
-    {
+    } else {
         recordemode = false;
         repaint();
         update();
@@ -1662,8 +1552,7 @@ qreal QvkRegionChoise::getXRecordArea()
     qreal xReal = ( frame_X + framePenWidth/2 ) * screen->devicePixelRatio();
     int xInt = static_cast<int>( ( frame_X + framePenWidth/2 ) * screen->devicePixelRatio() );
 
-    if ( xReal > xInt )
-    {
+    if ( xReal > xInt ) {
         xReal = xInt + 1;
     }
 
@@ -1679,8 +1568,7 @@ qreal QvkRegionChoise::getYRecordArea()
    qreal xReal = ( frame_Y + framePenWidth/2 ) * screen->devicePixelRatio();
    int xInt = static_cast<int>( ( frame_Y + framePenWidth/2 ) * screen->devicePixelRatio() );
 
-   if ( xReal > xInt )
-   {
+   if ( xReal > xInt ) {
        xReal = xInt + 1;
    }
 
@@ -1696,18 +1584,14 @@ qreal QvkRegionChoise::getHeight()
     qreal xReal =   ( ( frame_Y + framePenWidth/2 ) + ( frame_height - framePenWidth ) ) * screen->devicePixelRatio();
     int xInt = static_cast<int>( ( ( frame_Y + framePenWidth/2 ) + ( frame_height - framePenWidth ) ) * screen->devicePixelRatio() );
 
-    if ( xReal > xInt )
-    {
+    if ( xReal > xInt ) {
         xReal = static_cast<int>( ( frame_height - framePenWidth ) * screen->devicePixelRatio() ) - 1;
-    }
-    else
-    {
+    } else {
         xReal = static_cast<int>( ( frame_height - framePenWidth ) * screen->devicePixelRatio() );
     }
 
 #ifdef Q_OS_WIN
-    if ( ( xReal + getYRecordArea() ) == screen->size().height() )
-    {
+    if ( ( xReal + getYRecordArea() ) == screen->size().height() ) {
       xReal-=2;
     }
 #endif
@@ -1724,18 +1608,14 @@ qreal QvkRegionChoise::getWidth()
     qreal xReal = ( ( frame_X + framePenWidth/2 ) + ( frame_Width - framePenWidth ) ) * screen->devicePixelRatio();
     int xInt = static_cast<int>( ( ( frame_X + framePenWidth/2 ) + ( frame_Width - framePenWidth ) ) * screen->devicePixelRatio() );
 
-    if ( xReal > xInt )
-    {
+    if ( xReal > xInt ) {
         xReal = static_cast<int>( ( frame_Width - framePenWidth ) * screen->devicePixelRatio() ) - 1;
-    }
-    else
-    {
+    } else {
         xReal = static_cast<int>( ( frame_Width - framePenWidth ) * screen->devicePixelRatio() );
     }
 
 #ifdef Q_OS_WIN
-    if ( ( xReal + getXRecordArea() ) == screen->size().width() )
-    {
+    if ( ( xReal + getXRecordArea() ) == screen->size().width() ) {
       xReal-=2;
     }
 #endif
