@@ -58,10 +58,9 @@ void QvkScreenManager::slot_screen_count_changed()
     if ( !screen.empty() )
     {
         emit signal_clear_widget();
-        for ( int i = 0; i < screen.size(); i++ )
-        {
-            if ( screen.at(i)->name() == QGuiApplication::primaryScreen()->name() )
-            {
+        for ( int i = 0; i < screen.size(); i++ ) {
+            if ( screen.at(i)->name() == QGuiApplication::primaryScreen()->name() ) {
+                qDebug();
                 qDebug().noquote() << global::nameOutput << "This screen is the primary screen: " << QGuiApplication::primaryScreen()->name();
             }
             qDebug().noquote() << global::nameOutput << "Name from screen: " << screen.at(i)->name();
