@@ -28,6 +28,7 @@
 #include <QMouseEvent>
 #include <QColor>
 #include <QDateTime>
+#include <QDir>
 
 QvkSettings::QvkSettings()
 {
@@ -46,6 +47,14 @@ QvkSettings::QvkSettings()
         installSetting.setValue( "version", global::version );
     }
     installSetting.endGroup();
+
+#ifdef Q_OS_WIN
+    // Extra Verzeichnis für openh264 erstellen
+    QSettings openh264Settings( QSettings::IniFormat, QSettings::UserScope, QString( global::name + "-" + "openh264" + "-" + global::version ), global::name, Q_NULLPTR );
+    openh264Settings.beginGroup( global::name );
+    openh264Settings.setValue( "Version", global::version );
+    openh264Settings.endGroup();
+#endif
 }
 
 QvkSettings::~QvkSettings(){}
@@ -56,8 +65,7 @@ void QvkSettings::readAll( Ui_formMainWindow *ui_mainwindow, QMainWindow *parent
 
     // Clear all settings if checkBoxResetAtNextStart is set
     QList<QCheckBox *> listCheckBoxReset = ui_mainwindow->centralWidget->findChildren<QCheckBox *>();
-    for ( int i = 0; i < listCheckBoxReset.count(); i++ )
-    {
+    for ( int i = 0; i < listCheckBoxReset.count(); i++ ) {
         if ( ( listCheckBoxReset.at(i)->objectName() == "checkBoxResetAtNextStart" ) and
              ( settings.value( listCheckBoxReset.at(i)->objectName(), false ).toBool() == true ) )
         {
@@ -65,7 +73,6 @@ void QvkSettings::readAll( Ui_formMainWindow *ui_mainwindow, QMainWindow *parent
         }
     }
 
-
     // We want block the signals for shortcut ComboBox signals and set the default value
     QList<QComboBox *> listComboBoxShortcut = ui_mainwindow->centralWidget->findChildren<QComboBox *>();
     for ( int i = 0; i < listComboBoxShortcut.count(); i++ )
@@ -109,70 +116,50 @@ void QvkSettings::readAll( Ui_formMainWindow *ui_mainwindow, QMainWindow *parent
     QList<QComboBox *> listComboBox = ui_mainwindow->centralWidget->findChildren<QComboBox *>();
     for ( int i = 0; i < listComboBox.count(); i++ )
     {
+        // Language
+        if ( listComboBox.at(i)->objectName() == "comboBoxLanguage" ) {
+            // listComboBox.at(i)->removeItem( 20 ); // Nur zum testen. Index muß zuvor ermittelt werden.
+            int index;
+
+            // Wird eine Sprache in den Settings gefunden, wird diese wenn in der ComboBox vorhanden gesetzt
+            QString valueText = settings.value( listComboBox.at(i)->objectName(), "" ).toString();
+            index = listComboBox.at(i)->findText( valueText );
+            if ( index > -1 ) {
+                listComboBox.at(i)->setCurrentIndex( index );
+                continue;
+            }
+
+            // Systemsprache ist in der Combobox nicht vorhanden, es wird "en" gesetzt
+            index = listComboBox.at(i)->findData( QLocale::system().name() );
+            if ( index == -1 ) {
+                int value = listComboBox.at(i)->findData( "en" );
+                listComboBox.at(i)->setCurrentIndex( value );
+                continue;
+            }
+
+            // Systemsprache wird in der Combobox gesetzt wenn diese in der Combobox gefunden wird.
+            index = listComboBox.at(i)->findData( QLocale::system().name() );
+            if ( index > -1 ) {
+                listComboBox.at(i)->setCurrentIndex( index );
+            }
+
+            continue;
+        }
+
         QString valueText = settings.value( listComboBox.at(i)->objectName(), "" ).toString();
         int valueInt = listComboBox.at(i)->findText( valueText );
-        if ( valueInt > -1 )
-        {
+        if ( valueInt > -1 ) {
             listComboBox.at(i)->setCurrentIndex( valueInt );
         }
     }
 
     // After set all comboBox values we set the shortcut ComboBox signals
-    for ( int i = 0; i < listComboBoxShortcut.count(); i++ )
-    {
-        if ( listComboBoxShortcut.at(i)->objectName().contains( "comboBox_shortcut", Qt::CaseInsensitive ) == true )
-        {
+    for ( int i = 0; i < listComboBoxShortcut.count(); i++ ) {
+        if ( listComboBoxShortcut.at(i)->objectName().contains( "comboBox_shortcut", Qt::CaseInsensitive ) == true ) {
             listComboBoxShortcut.at(i)->blockSignals( false );
         }
     }
 
-
-    // These settings must be set in this order: Format, Videocodec, Audiocodec
-    // 1. Format
-    QList<QComboBox *> listComboBoxFormat = ui_mainwindow->centralWidget->findChildren<QComboBox *>();
-    for ( int i = 0; i < listComboBoxFormat.count(); i++ )
-    {
-        if ( listComboBoxFormat.at(i)->objectName() == "comboBoxFormat" )
-        {
-            QString valueText = settings.value( listComboBoxFormat.at(i)->objectName(), "" ).toString();
-            int valueInt = listComboBoxFormat.at(i)->findText( valueText );
-            if ( valueInt > -1 )
-            {
-                listComboBoxFormat.at(i)->setCurrentIndex( valueInt );
-            }
-        }
-    }
-
-    // 2. Videocodec
-    QList<QComboBox *> listComboBoxVideo = ui_mainwindow->centralWidget->findChildren<QComboBox *>();
-    for ( int i = 0; i < listComboBoxVideo.count(); i++ )
-    {
-        if ( listComboBoxVideo.at(i)->objectName() == "comboBoxVideoCodec" )
-        {
-            QString valueText = settings.value( listComboBoxVideo.at(i)->objectName(), "" ).toString();
-            int valueInt = listComboBoxVideo.at(i)->findText( valueText );
-            if ( valueInt > -1 )
-            {
-                listComboBoxVideo.at(i)->setCurrentIndex( valueInt );
-            }
-        }
-    }
-
-    // 3. Audiocodec
-    QList<QComboBox *> listComboBoxAudio = ui_mainwindow->centralWidget->findChildren<QComboBox *>();
-    for ( int i = 0; i < listComboBoxAudio.count(); i++ )
-    {
-        if ( listComboBoxAudio.at(i)->objectName() == "comboBoxAudioCodec" )
-        {
-            QString valueText = settings.value( listComboBoxAudio.at(i)->objectName(), "" ).toString();
-            int valueInt = listComboBoxAudio.at(i)->findText( valueText );
-            if ( valueInt > -1 )
-            {
-                listComboBoxAudio.at(i)->setCurrentIndex( valueInt );
-            }
-        }
-    }
-
     QList<QRadioButton *> listRadiobuttons = ui_mainwindow->centralWidget->findChildren<QRadioButton *>();
     for ( int i = 0; i < listRadiobuttons.count(); i++ )
     {
@@ -376,8 +363,13 @@ void QvkSettings::readAll( Ui_formMainWindow *ui_mainwindow, QMainWindow *parent
 
 
         if ( ( listCheckBox.at(i)->objectName().contains( "checkBoxSnapshotHideBeforeRecording" ) ) and
-             ( settings.value( listCheckBox.at(i)->objectName(), true ).toBool() == true ) )
-        {
+             ( settings.value( listCheckBox.at(i)->objectName(), true ).toBool() == true ) ) {
+            listCheckBox.at(i)->click();
+            continue;
+        }
+
+        if ( ( listCheckBox.at(i)->objectName().contains( "checkBoxGifLoop" ) ) and
+            ( settings.value( listCheckBox.at(i)->objectName(), true ).toBool() == true ) ) {
             listCheckBox.at(i)->click();
             continue;
         }
@@ -392,31 +384,25 @@ void QvkSettings::readAll( Ui_formMainWindow *ui_mainwindow, QMainWindow *parent
     QList<QSlider *> listSlider = ui_mainwindow->centralWidget->findChildren<QSlider *>();
     for ( int i = 0; i < listSlider.count(); i++ )
     {
-        if ( listSlider.at(i)->objectName() == "sliderVideo" )
-        {
+        if ( listSlider.at(i)->objectName() == "sliderVideo" ) {
             continue;
         }
 
-        if ( listSlider.at(i)->objectName() == "sliderGstDebugLevel" )
-        {
+        if ( listSlider.at(i)->objectName() == "sliderGstDebugLevel" ) {
             continue;
         }
 
         QVariant variant = settings.value( listSlider.at(i)->objectName() );
-        if ( variant.isValid() )
-        {
+        if ( variant.isValid() ) {
             listSlider.at(i)->setValue( variant.toInt() );
         }
     }
 
     QList<QLineEdit *> listLineEdit = ui_mainwindow->centralWidget->findChildren<QLineEdit *>();
-    for ( int i = 0; i < listLineEdit.count(); i++ )
-    {
-        if ( listLineEdit.at(i)->objectName().contains( "lineEdit" ) )
-        {
+    for ( int i = 0; i < listLineEdit.count(); i++ ) {
+        if ( listLineEdit.at(i)->objectName().contains( "lineEdit" ) ) {
             QString value = settings.value( listLineEdit.at(i)->objectName() ).toString();
-            if ( !value.isEmpty() )
-            {
+            if ( !value.isEmpty() ) {
                 listLineEdit.at(i)->setText( value );
             }
         }
@@ -424,8 +410,7 @@ void QvkSettings::readAll( Ui_formMainWindow *ui_mainwindow, QMainWindow *parent
 
     // All TabWidget start with value=0, also if in Qt-Creator is the value an other
     QList<QTabWidget *> listTabWidget = ui_mainwindow->centralWidget->findChildren<QTabWidget *>();
-    for ( int i = 0; i < listTabWidget.count(); i++ )
-    {
+    for ( int i = 0; i < listTabWidget.count(); i++ ) {
         listTabWidget.at(i)->setCurrentIndex( 0 );
 
         QvkSettings vkSettingsGstDebug;
@@ -440,8 +425,7 @@ void QvkSettings::readAll( Ui_formMainWindow *ui_mainwindow, QMainWindow *parent
     }
 
     QList<QToolButton *> listToolButton = ui_mainwindow->centralWidget->findChildren<QToolButton *>();
-    for ( int i = 0; i < listToolButton.count(); i++ )
-    {
+    for ( int i = 0; i < listToolButton.count(); i++ ) {
         if ( listToolButton.at(i)->objectName().contains( "toolButtonMute" ) ) {
             QString value = settings.value( listToolButton.at(i)->objectName() ).toString();
             if ( value == "audio-volume-muted") {
@@ -482,10 +466,8 @@ void QvkSettings::readAll( Ui_formMainWindow *ui_mainwindow, QMainWindow *parent
     }
 
     QList<QvkSpezialCheckbox *> listSpezialCheckbox = ui_mainwindow->centralWidget->findChildren<QvkSpezialCheckbox *>();
-    for ( int i = 0; i < listSpezialCheckbox.count(); i++ )
-    {
-        if ( settings.value( listSpezialCheckbox.at(i)->objectName(), false ).toBool() == true )
-        {
+    for ( int i = 0; i < listSpezialCheckbox.count(); i++ ) {
+        if ( settings.value( listSpezialCheckbox.at(i)->objectName(), false ).toBool() == true ) {
             emit listSpezialCheckbox.at(i)->signal_clicked( true );
         }
     }
@@ -498,89 +480,79 @@ void QvkSettings::saveAll(Ui_formMainWindow *ui_mainwindow , QMainWindow *parent
 {
     Q_UNUSED(parent);
     QSettings settings( QSettings::IniFormat, QSettings::UserScope, global::name, global::name, Q_NULLPTR );
-    if ( log == true )
-    {
+    if ( log == true ) {
         // do nothing
-    }
-    else
+    } else {
         settings.clear();
+    }
 
     settings.beginGroup( global::name );
-    if ( log == true )
-    {
+    if ( log == true ) {
         // do nothing
-    }
-    else
+    } else {
         settings.setValue( "Version", global::version );
+    }
     settings.endGroup();
 
     QList<QRadioButton *> listRadiobuttons = ui_mainwindow->centralWidget->findChildren<QRadioButton *>();
-    for ( int i = 0; i < listRadiobuttons.count(); i++ )
-    {
-        if ( log == true )
+    for ( int i = 0; i < listRadiobuttons.count(); i++ ) {
+        if ( log == true ) {
             qDebug().noquote() << global::nameOutput << listRadiobuttons.at(i)->objectName() << "=" << listRadiobuttons.at(i)->isChecked();
-        else
+        } else {
             settings.setValue( listRadiobuttons.at(i)->objectName(), listRadiobuttons.at(i)->isChecked() );
+        }
     }
 
     QList<QCheckBox *> listCheckBox = ui_mainwindow->centralWidget->findChildren<QCheckBox *>();
-    for ( int i = 0; i < listCheckBox.count(); i++ )
-    {
+    for ( int i = 0; i < listCheckBox.count(); i++ ) {
         if ( ( listCheckBox.at(i)->objectName() == "checkBoxStopRecordingAfter" ) or
              ( listCheckBox.at(i)->objectName() == "checkBoxStartTime" ) )
         {
             // We do not save
-        }
-        else
-        {
-            if ( log == true )
+        } else {
+            if ( log == true ) {
                 qDebug().noquote() << global::nameOutput << listCheckBox.at(i)->objectName() << "=" << listCheckBox.at(i)->isChecked();
-            else
+            } else {
                 settings.setValue( listCheckBox.at(i)->objectName(), listCheckBox.at(i)->isChecked() );
+            }
         }
     }
 
     QList<QComboBox *> listComboBox = ui_mainwindow->centralWidget->findChildren<QComboBox *>();
-    for ( int i = 0; i < listComboBox.count(); i++ )
-    {
-        if ( log == true )
+    for ( int i = 0; i < listComboBox.count(); i++ ) {
+        if ( log == true ) {
             qDebug().noquote() << global::nameOutput << listComboBox.at(i)->objectName() << "=" << listComboBox.at(i)->currentText();
-        else
+        } else {
             settings.setValue( listComboBox.at(i)->objectName(), listComboBox.at(i)->currentText() );
+        }
     }
 
     QList<QSlider *> listSlider = ui_mainwindow->centralWidget->findChildren<QSlider *>();
-    for ( int i = 0; i < listSlider.count(); i++ )
-    {
-        if ( log == true )
+    for ( int i = 0; i < listSlider.count(); i++ ) {
+        if ( log == true ) {
             qDebug().noquote() << global::nameOutput << listSlider.at(i)->objectName() << "=" << listSlider.at(i)->value();
-        else
+        } else {
             settings.setValue( listSlider.at(i)->objectName(), listSlider.at(i)->value() );
+        }
     }
 
     QList<QLineEdit *> listLineEdit = ui_mainwindow->centralWidget->findChildren<QLineEdit *>();
-    for ( int i = 0; i < listLineEdit.count(); i++ )
-    {
-        if ( listLineEdit.at(i)->objectName().contains( "lineEdit" ) )
-        {
-            if ( log == true )
+    for ( int i = 0; i < listLineEdit.count(); i++ ) {
+        if ( listLineEdit.at(i)->objectName().contains( "lineEdit" ) ) {
+            if ( log == true ) {
                 qDebug().noquote() << global::nameOutput << listLineEdit.at(i)->objectName() << "=" << listLineEdit.at(i)->text();
-            else
+            } else {
                 settings.setValue( listLineEdit.at(i)->objectName(), listLineEdit.at(i)->text() );
+            }
         }
     }
 
     QList<QToolButton *> listToolButton = ui_mainwindow->centralWidget->findChildren<QToolButton *>();
-    for ( int i = 0; i < listToolButton.count(); i++ )
-    {
-        if ( listToolButton.at(i)->objectName().contains( "toolButtonMute" ) )
-        {
-            if ( listToolButton.at(i)->isChecked() == true )
-            {
+    for ( int i = 0; i < listToolButton.count(); i++ ) {
+        if ( listToolButton.at(i)->objectName().contains( "toolButtonMute" ) ) {
+            if ( listToolButton.at(i)->isChecked() == true ) {
                 settings.setValue( listToolButton.at(i)->objectName(), "audio-volume-muted" );
-            }
-            else
-            {
+            } else {
                 settings.setValue( listToolButton.at(i)->objectName(), "audio-volume-high" );
             }
         }
@@ -595,8 +567,7 @@ void QvkSettings::saveAll(Ui_formMainWindow *ui_mainwindow , QMainWindow *parent
     }
 
     QList<QvkSpezialCheckbox *> listSpezialCheckbox = ui_mainwindow->centralWidget->findChildren<QvkSpezialCheckbox *>();
-    for ( int i = 0; i < listSpezialCheckbox.count(); i++ )
-    {
+    for ( int i = 0; i < listSpezialCheckbox.count(); i++ ) {
         settings.setValue( listSpezialCheckbox.at(i)->objectName(), listSpezialCheckbox.at(i)->isChecked() );
     }
 }
@@ -607,6 +578,15 @@ QString QvkSettings::getFileName()
     return settings.fileName();
 }
 
+
+QString QvkSettings::getOpenh264ProfilePathWithFilename()
+{
+    QSettings openh264Settings( QSettings::IniFormat, QSettings::UserScope, QString( global::name + "-" + "openh264" + "-" + global::version ), global::name, Q_NULLPTR );
+    QFileInfo fileInfo( openh264Settings.fileName() );
+    return fileInfo.absoluteFilePath();
+}
+
+
 QString QvkSettings::getVideoPath()
 {
     QSettings settings( QSettings::IniFormat, QSettings::UserScope, global::name, global::name, Q_NULLPTR );
@@ -650,7 +630,22 @@ void QvkSettings::readCamera( QvkCameraController *vkCameraController )
     settings.beginGroup( "Camera" );
 #if (QT_VERSION <= QT_VERSION_CHECK(6, 0, 0))
     // Qt5
+#ifdef Q_OS_LINUX
     vkCameraController->vkCameraWindow->move( settings.value( "X", 0 ).toInt(), settings.value( "Y", 0 ).toInt() );
+#endif
+
+#ifdef Q_OS_WIN
+    vkCameraController->old_XY.setX( settings.value( "X", 0 ).toInt() );
+    vkCameraController->old_XY.setY( settings.value( "Y", 0 ).toInt() );
+    QList<QCheckBox *> listCheckBox = vkCameraController->ui_formMainWindow->centralWidget->findChildren<QCheckBox *>();
+    for ( int i = 0; i < listCheckBox.count(); i++ ) {
+        if ( listCheckBox.at(i)->objectName() == "checkBoxCameraOnOff" ) {
+            if ( listCheckBox.at(i)->isChecked() == true ) {
+                vkCameraController->vkCameraWindow->move( settings.value( "X", 0 ).toInt(), settings.value( "Y", 0 ).toInt() );
+            }
+        }
+    }
+#endif
 #else
     // Qt6
 #endif
@@ -674,8 +669,7 @@ void QvkSettings::readSystrayAlternative( QvkSystrayAlternative *vkSystrayAltern
     settings.endGroup();
 }
 
-#if (QT_VERSION <= QT_VERSION_CHECK(6, 0, 0))
-    // Qt5
+
 void QvkSettings::savePlayerPathOpenFile( QString pathFile )
 {
     QSettings settings( QSettings::IniFormat, QSettings::UserScope, global::name, global::name, Q_NULLPTR );
@@ -687,16 +681,15 @@ void QvkSettings::savePlayerPathOpenFile( QString pathFile )
     settings.endGroup();
 }
 
-void QvkSettings::readPlayerPathOpenFile( QvkPlayer *vkplayer )
+
+void QvkSettings::readPlayerPathOpenFile( int value, QvkPlayerController *vkplayer )
 {
+    Q_UNUSED(value)
     QSettings settings( QSettings::IniFormat, QSettings::UserScope, global::name, global::name, Q_NULLPTR );
     settings.beginGroup( "Player" );
     vkplayer->pathOpenFile = settings.value( "Path", "" ).toString();
     settings.endGroup();
 }
-#else
-    // Qt6
-#endif
 
 void QvkSettings::saveHaloColor( QColor value )
 {
