@@ -26,13 +26,7 @@
 #include "QvkRegionChoise.h"
 #include "QvkCameraController.h"
 #include "QvkSystrayAlternative.h"
-#if (QT_VERSION <= QT_VERSION_CHECK(6, 0, 0))
-    // Qt5
-#include "QvkPlayer.h"
-#else
-    // Qt6
-#endif
-
+#include "QvkPlayerController.h"
 #include "QvkHalo.h"
 #include "QvkShowClick.h"
 
@@ -60,13 +54,8 @@ public:
     void saveSystrayAlternative( int x, int y );
     void readSystrayAlternative( QvkSystrayAlternative *vkSystrayAlternative );
 
-#if (QT_VERSION <= QT_VERSION_CHECK(6, 0, 0))
-    // Qt5
     void savePlayerPathOpenFile( QString pathFile );
-    void readPlayerPathOpenFile( QvkPlayer *vkplayer );
-#else
-    // Qt6
-#endif
+    void readPlayerPathOpenFile( int dummy, QvkPlayerController *vkplayer );
 
     void saveHaloColor( QColor color );
     void readHaloColor( QvkHalo *vkHalo );
@@ -76,6 +65,7 @@ public:
 
     QString getFileName();
     QString getVideoPath();
+    QString getOpenh264ProfilePathWithFilename();
 
 
 public slots:
