@@ -32,14 +32,13 @@
 #include "global.h"
 #include "QvkSnapshot.h"
 #include "QvkSpezialSlider.h"
-#include "QvkDirDialog.h"
+#include "qvkdirdialog.h"
 #include "QvkShowMessage.h"
 
-
-QvkSnapshot::QvkSnapshot( QvkMainWindow *_vkMainWindow, Ui_formMainWindow *ui_formMainWindow )
+QvkSnapshot::QvkSnapshot( QvkMainWindow *myParent )
 {
-    ui = ui_formMainWindow;
-    vkMainWindow = _vkMainWindow;
+    vkMainWindow = myParent;
+    ui = vkMainWindow->ui;
 }
 
 
@@ -63,8 +62,7 @@ void QvkSnapshot::init()
 void QvkSnapshot::supportedImageFormats()
 {
     QList<QByteArray> listFormats = QImageWriter::supportedImageFormats();
-    if ( listFormats.empty() == false )
-    {
+    if ( listFormats.empty() == false ) {
         for ( int x = 0; x < listFormats.count(); x++ ) {
             ui->comboBoxSnapshotImageFormats->addItem( QString( listFormats.at(x) ) );
         }
@@ -79,11 +77,11 @@ void QvkSnapshot::slot_newImage()
     myScreen = QGuiApplication::screens();
     filename = global::name + "-" + QDateTime::currentDateTime().toString( "yyyy-MM-dd_hh-mm-ss.zzz" ) + "." + ui->comboBoxSnapshotImageFormats->currentText().toUtf8();
 
-    if ( ui->radioButtonScreencastFullscreen->isChecked() == true )
-    {
-        bool wasVisible = false;
-        if ( ( ui->checkBoxSnapshotHideBeforeRecording->isChecked() == true ) and ( vkMainWindow->isMinimized() == false ) ) {
-            wasVisible = true;
+    if ( ui->radioButtonScreencastFullscreen->isChecked() == true ) {
+        Qt::ApplicationStates wasApplicationStates = QGuiApplication::applicationState();
+
+        bool wasMinimized = vkMainWindow->isMinimized();
+        if ( ( ui->checkBoxSnapshotHideBeforeRecording->isChecked() == true ) and ( wasMinimized  == false ) ) {
             vkMainWindow->showMinimized();
         }
 
@@ -109,15 +107,18 @@ void QvkSnapshot::slot_newImage()
             }
         }
 
-        if ( ( ui->checkBoxSnapshotHideBeforeRecording->isChecked() == true ) and ( wasVisible == true ) ) {
+        if ( ( ui->checkBoxSnapshotHideBeforeRecording->isChecked() == true ) and ( wasMinimized == false ) ) {
             vkMainWindow->showNormal();
         }
+
+        if ( wasApplicationStates == Qt::ApplicationActive ) {
+            vkMainWindow->activateWindow();
+            vkMainWindow->raise();
+        }
     }
 
-    if ( ui->radioButtonScreencastWindow->isChecked() == true )
-    {
-        if ( ui->pushButtonStart->isEnabled() == true )
-        {
+    if ( ui->radioButtonScreencastWindow->isChecked() == true ) {
+        if ( ui->pushButtonStart->isEnabled() == true ) {
             vkWinInfo = new QvkWinInfo;
             disconnect( vkWinInfo, nullptr, nullptr, nullptr );
             // The slot is triggered if no recording is running
@@ -146,11 +147,11 @@ void QvkSnapshot::slot_newImage()
         }
     }
 
-    if ( ui->radioButtonScreencastArea->isChecked() == true )
-    {
-        bool wasVisible = false;
-        if ( ( ui->checkBoxSnapshotHideBeforeRecording->isChecked() == true ) and ( vkMainWindow->isMinimized() == false ) ) {
-            wasVisible = true;
+    if ( ui->radioButtonScreencastArea->isChecked() == true ) {
+        Qt::ApplicationStates wasApplicationStates = QGuiApplication::applicationState();
+
+        bool wasMinimized = vkMainWindow->isMinimized();
+        if ( ( ui->checkBoxSnapshotHideBeforeRecording->isChecked() == true ) and ( wasMinimized == false ) ) {
             vkMainWindow->showMinimized();
         }
 
@@ -188,9 +189,14 @@ void QvkSnapshot::slot_newImage()
             vkMainWindow->vkRegionChoise->recordMode( false );
         }
 
-        if ( ( ui->checkBoxSnapshotHideBeforeRecording->isChecked() == true ) and ( wasVisible == true ) ) {
+        if ( ( ui->checkBoxSnapshotHideBeforeRecording->isChecked() == true ) and ( wasMinimized == false ) ) {
             vkMainWindow->showNormal();
         }
+
+        if ( wasApplicationStates == Qt::ApplicationActive ) {
+            vkMainWindow->activateWindow();
+            vkMainWindow->raise();
+        }
     }
 }
 
@@ -199,8 +205,7 @@ bool QvkSnapshot::is_imageFolderExists_and_haveWritePermission()
 {
     // Create Folder if not exists
     QDir dir( ui->lineEditSnapshotImagePath->text() );
-    if ( !dir.exists() )
-    {
+    if ( !dir.exists() ) {
         // check of QStandardPaths::MoviesLocation
         QDir dir( QStandardPaths::writableLocation( QStandardPaths::PicturesLocation ) );
         if ( !dir.exists() ) {
@@ -218,18 +223,15 @@ bool QvkSnapshot::is_imageFolderExists_and_haveWritePermission()
     bool value;
     QFileInfo fileInfo( filename );
     QFile file( filename );
-    if ( file.open( QIODevice::ReadWrite ) )
-    {
+    if ( file.open( QIODevice::ReadWrite ) ) {
         QTextStream stream( &file );
         stream << "Test Test Test Test Test Test" << Qt::endl;
         file.close();
-        qDebug().noquote();
         qDebug().noquote() << global::nameOutput << "Pictures permission: Can write in" << fileInfo.absolutePath();
         qDebug().noquote();
         file.remove();
         value = true;
     } else {
-        qDebug().noquote();
         qDebug().noquote() << "Pictures permission: ERROR can not write in" << fileInfo.absolutePath();
         qDebug().noquote();
         QPixmap pixmap( ":/pictures/status/warning.png" );
@@ -286,17 +288,12 @@ void QvkSnapshot::slot_snapshotWindow( bool )
 
 void QvkSnapshot::slot_imagePath()
 {
-    QApplication::setDesktopSettingsAware( false );
-
-    QvkDirDialog vkDirDialog( this );
-    if ( vkDirDialog.exec() == QDialog::Accepted )
-    {
-        if ( !vkDirDialog.selectedFiles().empty() ) {
-            ui->lineEditSnapshotImagePath->setText( vkDirDialog.selectedFiles().at(0) );
+    QvkDirDialog *vkDirDialog = new QvkDirDialog;
+    if ( vkDirDialog->exec() == QDialog::Accepted ) {
+        if ( !vkDirDialog->selectedFiles().empty() ) {
+            ui->lineEditSnapshotImagePath->setText( vkDirDialog->selectedFiles().at(0) );
         }
     }
-
-    QApplication::setDesktopSettingsAware( true );
 }
 
 
@@ -304,8 +301,7 @@ void QvkSnapshot::slot_Folder()
 {
     QString path = ui->lineEditSnapshotImagePath->text();
 
-    if ( QDesktopServices::openUrl( QUrl( "file:///" + path, QUrl::TolerantMode ) ) == false )
-    {
+    if ( QDesktopServices::openUrl( QUrl( "file:///" + path, QUrl::TolerantMode ) ) == false ) {
         QPixmap pixmap( ":/pictures/status/information.png" );
         pixmap = pixmap.scaled( 64, 64, Qt::IgnoreAspectRatio, Qt::SmoothTransformation );
 
