@@ -3,6 +3,7 @@
 
 #include <QDebug>
 #include <QPainterPath>
+#include <QThread>
 
 QvkSpezialCheckbox::QvkSpezialCheckbox( QWidget *parent ) : QWidget( parent )
 {
@@ -21,21 +22,27 @@ bool QvkSpezialCheckbox::isChecked()
 }
 
 
+void QvkSpezialCheckbox::set_waitBeforeTrigger( int value )
+{
+    waitBeforeTrigger = value;
+}
+
+
 void QvkSpezialCheckbox::slot_setChecked( bool value )
 {
      checked = value;
+     if ( waitBeforeTrigger > 0 ) {
+         QThread::msleep( waitBeforeTrigger );
+     }
      repaint();
 }
 
 
 void QvkSpezialCheckbox::slot_click()
 {
-    if ( checked == true )
-    {
+    if ( checked == true ) {
         checked = false;
-    }
-    else
-    {
+    } else {
         checked = true;
     }
 
@@ -49,12 +56,9 @@ void QvkSpezialCheckbox::mouseReleaseEvent(QMouseEvent *event)
 {
     Q_UNUSED(event);
 
-    if ( checked == true )
-    {
+    if ( checked == true ) {
         checked = false;
-    }
-    else
-    {
+    } else {
         checked = true;
     }
 
@@ -78,24 +82,47 @@ void QvkSpezialCheckbox::paintEvent( QPaintEvent *event )
     radius = 11;
     margin = 3;
 
-    if ( isChecked() == false )
-    {
+    if ( isChecked() == false ) {
         paintUnChecked( painter );
     }
 
-    if ( isChecked() == true )
-    {
+    if ( isChecked() == true ) {
         paintChecked( painter );
     }
 }
 
+
+void QvkSpezialCheckbox::set_colorChecked( QColor color )
+{
+    colorChecked = color;
+}
+
+
+void QvkSpezialCheckbox::set_colorUnChecked( QColor color )
+{
+    colorUnChecked = color;
+}
+
+
+void QvkSpezialCheckbox::set_imageChecked( QString value )
+{
+    imageChecked = value;
+}
+
+
+void QvkSpezialCheckbox::set_imageUnChecked( QString value )
+{
+    imageUnChecked = value;
+}
+
+
 void QvkSpezialCheckbox::paintChecked( QPainter &painter )
 {
     QPen pen;
     pen.setColor( Qt::black );
     pen.setWidthF( penWidth );
     painter.setPen( pen );
-    QBrush brushButton( Qt::darkGreen );
+    QBrush brushButton( colorChecked );
     painter.setBrush( brushButton );
     QRectF rectButton( button_x, button_y, button_width, button_height );
     painter.setBrush( brushButton );
@@ -121,8 +148,7 @@ void QvkSpezialCheckbox::paintChecked( QPainter &painter )
     QBrush brushRibs( Qt::darkGray );
     painter.setBrush( brushRibs );
     int step = 5;
-    for ( int x = 0; x < 10; x++ )
-    {
+    for ( int x = 0; x < 10; x++ ) {
        int value = step * x;
 
        painter.drawRect( slider_x + radius/2 + value,
@@ -131,12 +157,15 @@ void QvkSpezialCheckbox::paintChecked( QPainter &painter )
                          slider_height - 2 * margin);
     }
 
-    QPixmap pixmap( ":/pictures/spezialCheckBox/on.png" );
-    pixmap.setDevicePixelRatio( devicePixelRatioF() );
-    pixmap = pixmap.scaled( slider_height / 5 * 3 * devicePixelRatioF(), slider_height / 5 * 3 * devicePixelRatioF(), Qt::IgnoreAspectRatio, Qt::SmoothTransformation );
-    painter.drawPixmap( button_x + margin + ( ( slider_x - button_x - margin ) / 2 ) - ( pixmap.width() / 2 / devicePixelRatioF() ),
-                        button_y + margin + ( slider_height / 5 ),
-                        pixmap );
+    if ( imageChecked.isNull() == false ) {
+        QPixmap pixmap( imageChecked );
+        pixmap.setDevicePixelRatio( devicePixelRatioF() );
+        pixmap = pixmap.scaled( slider_height / 5 * 3 * devicePixelRatioF(), slider_height / 5 * 3 * devicePixelRatioF(), Qt::IgnoreAspectRatio, Qt::SmoothTransformation );
+        painter.drawPixmap( button_x + margin + ( ( slider_x - button_x - margin ) / 2 ) - ( pixmap.width() / 2 / devicePixelRatioF() ),
+                            button_y + margin + ( slider_height / 5 ),
+                            pixmap );
+    }
+
 }
 
 
@@ -146,7 +175,7 @@ void QvkSpezialCheckbox::paintUnChecked( QPainter &painter )
     pen.setWidthF( penWidth );
     pen.setColor( Qt::black );
     painter.setPen( pen );
-    QBrush brushButton( Qt::darkRed );
+    QBrush brushButton( colorUnChecked );
     painter.setBrush( brushButton );
     QRectF rectButton( button_x, button_y, button_width, button_height );
     painter.setBrush( brushButton );
@@ -172,8 +201,7 @@ void QvkSpezialCheckbox::paintUnChecked( QPainter &painter )
     QBrush brushRibs( Qt::darkGray );
     painter.setBrush( brushRibs );
     int step = 5;
-    for ( int x = 0; x < 10; x++ )
-    {
+    for ( int x = 0; x < 10; x++ ) {
        int value = step * x;
 
        painter.drawRect( slider_x + radius/2 + value,
@@ -182,11 +210,14 @@ void QvkSpezialCheckbox::paintUnChecked( QPainter &painter )
                          slider_height - 2 * margin);
     }
 
-    QPixmap pixmap( ":/pictures/spezialCheckBox/off.png" );
-    pixmap.setDevicePixelRatio(  devicePixelRatioF() );
-    pixmap = pixmap.scaled( slider_height / 5 * 3 * devicePixelRatioF(),
-                            slider_height / 5 * 3 * devicePixelRatioF(), Qt::IgnoreAspectRatio, Qt::SmoothTransformation );
-    painter.drawPixmap( slider_x+slider_width + ( button_width - slider_x - slider_width) / 2 - pixmap.width() / 2 / devicePixelRatioF(),
-                        button_y + margin + ( slider_height / 5 ),
-                        pixmap );
+    if ( imageChecked.isNull() == false ) {
+        QPixmap pixmap( imageUnChecked );
+        pixmap.setDevicePixelRatio(  devicePixelRatioF() );
+        pixmap = pixmap.scaled( slider_height / 5 * 3 * devicePixelRatioF(),
+                                slider_height / 5 * 3 * devicePixelRatioF(), Qt::IgnoreAspectRatio, Qt::SmoothTransformation );
+        painter.drawPixmap( slider_x+slider_width + ( button_width - slider_x - slider_width) / 2 - pixmap.width() / 2 / devicePixelRatioF(),
+                            button_y + margin + ( slider_height / 5 ),
+                            pixmap );
+    }
+
 }
