@@ -29,37 +29,31 @@ QvkSystrayAlternative::QvkSystrayAlternative( QMainWindow *mainWindow, Ui_formMa
 
     startAction = new QAction( this );
     startAction->setIcon( QIcon( ":/pictures/player/start.png" ) );
-    startAction->setText( tr( "Start" ) );
     startAction->setData( "Start" );
 
     stopAction = new QAction( this );
     stopAction->setIcon( QIcon( ":/pictures/player/stop.png" ) );
-    stopAction->setText( tr( "Stop" ) );
     stopAction->setData( "Stop" );
     stopAction->setEnabled( false );
 
     pauseAction = new QAction( this );
     pauseAction->setIcon( QIcon( ":/pictures/player/pause.png" ) );
-    pauseAction->setText( tr( "Pause" ) );
     pauseAction->setData( "Pause" );
     pauseAction->setEnabled( false );
 
     continueAction = new QAction( this );
     continueAction->setIcon( QIcon( ":/pictures/player/start.png" ));
-    continueAction->setText( tr( "Continue" ) );
     continueAction->setData( "Continue" );
     continueAction->setEnabled( false );
 
     cameraAction = new QAction( this );
     cameraAction->setIcon( QIcon( ":pictures/systray/camera.png" ) );
-    cameraAction->setText( tr( "Camera" ) );
     cameraAction->setData( "Camera" );
     cameraAction->setCheckable( true );
     cameraAction->setEnabled( false );
 
     magnifierAction = new QAction( this );
     magnifierAction->setIcon( QIcon( ":pictures/systray/magnification.png" ) );
-    magnifierAction->setText( tr( "Magnification" ) );
     magnifierAction->setData( "Magnification" );
     magnifierAction->setCheckable( true );
 
@@ -83,7 +77,6 @@ QvkSystrayAlternative::QvkSystrayAlternative( QMainWindow *mainWindow, Ui_formMa
 
     exitAction = new QAction( this );
     exitAction->setIcon( QIcon( ":/pictures/systray/exit.png" ) );
-    exitAction->setText( tr( "Exit" ) );
     exitAction->setData( "Exit" );
 
     connect( ui->pushButtonStart, SIGNAL( clicked( bool ) ), startAction,    SLOT( setEnabled( bool ) ) );
@@ -161,6 +154,8 @@ QvkSystrayAlternative::QvkSystrayAlternative( QMainWindow *mainWindow, Ui_formMa
     menu->addAction( exitAction );
 
     vkSystrayAlternativeWindow->set_Menu( menu );
+
+    setMenueText();
 }
 
 
@@ -169,12 +164,25 @@ QvkSystrayAlternative::~QvkSystrayAlternative()
 }
 
 
+void QvkSystrayAlternative::setMenueText()
+{
+    startAction->setText( tr( "Start" ) );
+    stopAction->setText( tr( "Stop" ) );
+    pauseAction->setText( tr( "Pause" ) );
+    continueAction->setText( tr( "Continue" ) );
+    cameraAction->setText( tr( "Camera" ) );
+    magnifierAction->setText( tr( "Magnification" ) );
+    exitAction->setText( tr( "Exit" ) );
+}
+
+
 void QvkSystrayAlternative::slot_currentIndexChanged( int index )
 {
-    if ( index > -1 )
+    if ( index > -1 ) {
         cameraAction->setEnabled( true );
-    else
+    } else {
         cameraAction->setEnabled( false );
+    }
 }
 
 
@@ -188,18 +196,15 @@ void QvkSystrayAlternative::slot_resizeWindow( int value )
 {
     size = QSize( value, value );
 
-    if ( ui->pushButtonStart->isEnabled() == true )
-    {
+    if ( ui->pushButtonStart->isEnabled() == true ) {
         slot_setSystrayIcon( true );
     }
 
-    if ( ui->pushButtonStop->isEnabled() == true )
-    {
+    if ( ui->pushButtonStop->isEnabled() == true ) {
         slot_setRecordIcon( true );
     }
 
-    if ( ui->pushButtonContinue->isEnabled() == true )
-    {
+    if ( ui->pushButtonContinue->isEnabled() == true ) {
         slot_setPauseIcon( true );
     }
 }
@@ -238,77 +243,76 @@ void QvkSystrayAlternative::slot_ShowInSystrayAlternativeReset( bool )
 
 void QvkSystrayAlternative::slot_shortcutSystray( QString device, QString shortcut )
 {
-    if ( device == "Start" ){
+    if ( device == "Start" ) {
         startAction->setShortcutVisibleInContextMenu( true );
         startAction->setShortcut( QKeySequence::fromString( shortcut ) );
-        if ( shortcut == "None" ){
+        if ( shortcut == "None" ) {
             startAction->setShortcutVisibleInContextMenu( false );
         }
         return;
     }
 
-    if ( device == "Stop" ){
+    if ( device == "Stop" ) {
         stopAction->setShortcutVisibleInContextMenu( true );
         stopAction->setShortcut( QKeySequence::fromString( shortcut ) );
-        if ( shortcut == "None" ){
+        if ( shortcut == "None" ) {
             stopAction->setShortcutVisibleInContextMenu( false );
         }
     }
 
-    if ( device == "Pause" ){
+    if ( device == "Pause" ) {
         pauseAction->setShortcutVisibleInContextMenu( true );
         pauseAction->setShortcut( QKeySequence::fromString( shortcut ) );
-        if ( shortcut == "None" ){
+        if ( shortcut == "None" ) {
             pauseAction->setShortcutVisibleInContextMenu( false );
         }
     }
 
-    if ( device == "Continue" ){
+    if ( device == "Continue" ) {
         continueAction->setShortcutVisibleInContextMenu( true );
         continueAction->setShortcut( QKeySequence::fromString( shortcut ) );
-        if ( shortcut == "None" ){
+        if ( shortcut == "None" ) {
             continueAction->setShortcutVisibleInContextMenu( false );
         }
     }
 
-    if ( device == "camera" ){
+    if ( device == "camera" ) {
         cameraAction->setShortcutVisibleInContextMenu( true );
         cameraAction->setShortcut( QKeySequence::fromString( shortcut ) );
-        if ( shortcut == "None" ){
+        if ( shortcut == "None" ) {
             cameraAction->setShortcutVisibleInContextMenu( false );
         }
     }
 
-    if ( device == "magnification" ){
+    if ( device == "magnification" ) {
         magnifierAction->setShortcutVisibleInContextMenu( true );
         magnifierAction->setShortcut( QKeySequence::fromString( shortcut ) );
-        if ( shortcut == "None" ){
+        if ( shortcut == "None" ) {
             magnifierAction->setShortcutVisibleInContextMenu( false );
         }
     }
 
-    if ( device == "showclick" ){
+    if ( device == "showclick" ) {
         showclickAction->setShortcutVisibleInContextMenu( true );
         showclickAction->setShortcut( QKeySequence::fromString( shortcut ) );
-        if ( shortcut == "None" ){
+        if ( shortcut == "None" ) {
             showclickAction->setShortcutVisibleInContextMenu( false );
         }
     }
 
-    if ( device == "halo" ){
+    if ( device == "halo" ) {
         haloAction->setShortcutVisibleInContextMenu( true );
         haloAction->setShortcut( QKeySequence::fromString( shortcut ) );
-        if ( shortcut == "None" ){
+        if ( shortcut == "None" ) {
             haloAction->setShortcutVisibleInContextMenu( false );
         }
     }
 
-    if ( device == "snapshot" ){
+    if ( device == "snapshot" ) {
         snapshotAction->setShortcutVisibleInContextMenu( true );
         snapshotAction->setShortcut( QKeySequence::fromString( shortcut ) );
-        if ( shortcut == "None" ){
+        if ( shortcut == "None" ) {
             snapshotAction->setShortcutVisibleInContextMenu( false );
         }
     }
-
 }
