@@ -1,6 +1,7 @@
 #include "mainWindow_wl.h"
 #include "global.h"
-#include "QvkScreenManager.h"
+#include "QvkLicenses.h"
+#include "QvkImageFromTabs_wl.h"
 
 #include <QStringList>
 #include <QStandardPaths>
@@ -11,23 +12,46 @@
 #include <QStyleFactory>
 #include <QLibraryInfo>
 #include <QTimer>
+#include <QFile>
+#include <QToolButton>
 
 QvkMainWindow_wl::QvkMainWindow_wl( QWidget *parent, Qt::WindowFlags f )
     : QMainWindow(parent, f)
     , ui(new Ui::formMainWindow_wl)
 {
+    translator.load( QLocale::system().name(), ":/language" );
+    qApp->installTranslator( &translator );
+    qtTranslator.load( "qt_" + QLocale::system().name(), QLibraryInfo::location( QLibraryInfo::TranslationsPath ) );
+    qApp->installTranslator( &qtTranslator );
+
     ui->setupUi( this );
+
     set_LogController();
+
+    QFile fileCSS( ":/pictures/css/css.qss" );
+    fileCSS.open( QFile::ReadOnly | QFile::Text );
+    QTextStream streamCSS( &fileCSS );
+    qApp->setStyleSheet( streamCSS.readAll() );
+    fileCSS.close();
+
     set_WindowTitle();
     ui->tabWidgetScreencast->setCurrentIndex( 0 );
     ui->tabWidgetSideBar->setCurrentIndex( 0 );
     set_CornerWidget();
     set_system_info();
     set_SpezialSliders();
+    set_RegionChoice();
     set_Connects();
     set_check_all_Elements_available();
-    vkContainerController = new QvkContainerController( this, ui );
-    set_RegionChoice();
+    vkContainerController_wl = new QvkContainerController_wl( ui );
+    new QvkLicenses( ui->pushButtonLicense );
+    new QvkImageFromTabs_wl( this );
+
+    ui->labelSourcecodeUrl->setText( "<a href='https://github.com/vkohaupt/vokoscreenNG'>" + tr( "Sourcecode" ) + "</a>" );
+    ui->labelWebSiteUrl->setText( "<a href='https://linuxecke.volkoh.de/vokoscreen/vokoscreen.html'>" + tr( "Homepage" ) + "</a>" );
+    ui->labelLanguageUrl->setText( "<a href='https://app.transifex.com/vkohaupt/vokoscreen/'>" + tr( "Translations" ) + "</a>" );
+    ui->labelDonateUrl->setText( "<a href='https://linuxecke.volkoh.de/vokoscreen/vokoscreen-donate.html'>" + tr( "Donate" ) + "</a>" );
+
     ui->frame_information->hide();
     ui->pushButtonPause->hide();
     ui->pushButtonContinue->hide();
@@ -35,9 +59,14 @@ QvkMainWindow_wl::QvkMainWindow_wl( QWidget *parent, Qt::WindowFlags f )
     ui->pushButtonScreencastOpenfolder->hide();
     ui->frame_video_audio_on_off->hide();
     ui->comboBoxAudioCodec->hide();
-
+    ui->frame_cisco->hide();
+    ui->line_cisco->hide();
 
     ui->radioButtonScreencastFullscreen->click();
+
+    // Hide to time not needed tabs
+    ui->tabWidgetScreencast->removeTab(3); // Misc
+    ui->tabWidgetScreencast->removeTab(1); // Audio
 }
 
 
@@ -50,6 +79,7 @@ void QvkMainWindow_wl::closeEvent( QCloseEvent *event )
 {
     Q_UNUSED(event);
     ui->pushButtonStop->click();
+    vkRegionChoise_wl->close();
 }
 
 
@@ -107,8 +137,7 @@ void QvkMainWindow_wl::set_CornerWidget()
     QPixmap pixmap( ":/pictures/cornerWidget/wayland.png" );
     pixmap = pixmap.scaled( QSize( 48, 48 ), Qt::IgnoreAspectRatio, Qt::SmoothTransformation );
 
-    for ( int i = 0; i < list.count(); i++ )
-    {
+    for ( int i = 0; i < list.count(); i++ ) {
         QLabel *label = new QLabel();
         label->setPixmap( pixmap );
         label->setEnabled( false );
@@ -119,17 +148,26 @@ void QvkMainWindow_wl::set_CornerWidget()
 
 void QvkMainWindow_wl::set_Connects()
 {
-    connect( ui->pushButtonStart, SIGNAL( clicked( bool ) ), this,                 SLOT( slot_start() ) );
-    connect( ui->pushButtonStart, SIGNAL( clicked( bool ) ), ui->pushButtonStart,  SLOT( setEnabled( bool ) ) );
+    connect( ui->pushButtonStart, SIGNAL( clicked( bool ) ), ui->pushButtonStart,                 SLOT( setEnabled( bool ) ) );
+    connect( ui->pushButtonStart, SIGNAL( clicked( bool ) ), ui->radioButtonScreencastFullscreen, SLOT( setEnabled( bool ) ) );
+    connect( ui->pushButtonStart, SIGNAL( clicked( bool ) ), ui->radioButtonScreencastWindow,     SLOT( setEnabled( bool ) ) );
+    connect( ui->pushButtonStart, SIGNAL( clicked( bool ) ), ui->radioButtonScreencastArea,       SLOT( setEnabled( bool ) ) );
+    connect( ui->pushButtonStart, SIGNAL( clicked( bool ) ), ui->tabVideo,                        SLOT( setEnabled( bool ) ) );
+    connect( ui->pushButtonStart, SIGNAL( clicked( bool ) ), this,                                SLOT( slot_start() ) );
 
-    connect( ui->pushButtonStop,  SIGNAL( clicked( bool ) ), this,                 SLOT( slot_stop() ) );
-    connect( ui->pushButtonStop,  SIGNAL( clicked( bool ) ), ui->pushButtonStop,   SLOT( setEnabled( bool ) ) );
-    connect( ui->pushButtonStop,  SIGNAL( clicked( bool ) ), ui->pushButtonStart,  SLOT( setDisabled( bool ) ) );
+    connect( ui->pushButtonStop,  SIGNAL( clicked( bool ) ), this,                                SLOT( slot_stop() ) );
+    connect( ui->pushButtonStop,  SIGNAL( clicked( bool ) ), ui->pushButtonStop,                  SLOT( setEnabled( bool ) ) );
+    connect( ui->pushButtonStop,  SIGNAL( clicked( bool ) ), ui->pushButtonStart,                 SLOT( setDisabled( bool ) ) );
+    connect( ui->pushButtonStop,  SIGNAL( clicked( bool ) ), ui->radioButtonScreencastFullscreen, SLOT( setDisabled( bool ) ) );
+    connect( ui->pushButtonStop,  SIGNAL( clicked( bool ) ), ui->radioButtonScreencastWindow,     SLOT( setDisabled( bool ) ) );
+    connect( ui->pushButtonStop,  SIGNAL( clicked( bool ) ), ui->radioButtonScreencastArea,       SLOT( setDisabled( bool ) ) );
+    connect( ui->pushButtonStop,  SIGNAL( clicked( bool ) ), ui->tabVideo,                        SLOT( setDisabled( bool ) ) );
 
     connect( portal_wl, SIGNAL( signal_portal_fd_path( QString, QString ) ), this, SLOT( slot_start_gst( QString, QString ) ) );
     connect( portal_wl, SIGNAL( signal_portal_cancel( uint ) ), this,              SLOT( slot_portal_cancel( uint ) ) );
 
-    connect( ui->toolButtonFramesReset, SIGNAL( clicked( bool ) ), this,           SLOT( slot_frames_Reset() ) );
+    connect( ui->toolButtonScreencastAreaReset, SIGNAL( clicked( bool ) ), vkRegionChoise_wl, SLOT( slot_areaReset() ) );
+    connect( ui->toolButtonFramesReset,         SIGNAL( clicked( bool ) ), this,              SLOT( slot_frames_Reset() ) );
 }
 
 
@@ -138,8 +176,7 @@ QString QvkMainWindow_wl::get_Videocodec_Encoder()
     QString value;
     QString encoder = ui->comboBoxVideoCodec->currentData().toString();
 
-    if ( encoder == "openh264enc" )
-    {
+    if ( encoder == "openh264enc" ) {
         QStringList list;
         list << encoder;
         list << "qp-min=23"; // + QString::number( sliderOpenh264->value() );
@@ -152,8 +189,7 @@ QString QvkMainWindow_wl::get_Videocodec_Encoder()
         value.append( " ! h264parse" );
     }
 
-    if ( encoder == "x264enc" )
-    {
+    if ( encoder == "x264enc" ) {
         QStringList list;
         list << encoder;
         list << "qp-min=17"; // + QString::number( sliderOpenh264->value() );
@@ -164,8 +200,7 @@ QString QvkMainWindow_wl::get_Videocodec_Encoder()
         value.append( " ! video/x-h264, profile=baseline" );
     }
 
-    if ( encoder == "vp8enc" )
-    {
+    if ( encoder == "vp8enc" ) {
         QStringList list;
         list << encoder;
         list << "min_quantizer=20"; // + QString::number( sliderVp8->value() );
@@ -183,12 +218,9 @@ QString QvkMainWindow_wl::get_Videocodec_Encoder()
 QString QvkMainWindow_wl::get_Muxer()
 {
     QString value = ui->comboBoxFormat->currentData().toString();
-    if ( ui->comboBoxFormat->currentData().toString() == "matroskamux" )
-    {
+    if ( ui->comboBoxFormat->currentData().toString() == "matroskamux" ) {
         value = ui->comboBoxFormat->currentData().toString() + " name=mux writing-app=" + global::name + "_" + QString( global::version ).replace( " ", "_" );
-    }
-    else
-    {
+    } else {
         value = ui->comboBoxFormat->currentData().toString() + " name=mux";
     }
     return value;
@@ -201,20 +233,20 @@ void QvkMainWindow_wl::slot_start()
     // Value 1 = MONITOR
     // Value 2 = WINDOW
     int sourceType = 1;
-    if ( ui->radioButtonScreencastFullscreen->isChecked() )
-    {
+    if ( ui->radioButtonScreencastFullscreen->isChecked() ) {
+        qDebug();
         qDebug().noquote() << global::nameOutput << "Start portal fullscreen";
         sourceType = 1;
     }
 
-    if ( ui->radioButtonScreencastWindow->isChecked() )
-    {
+    if ( ui->radioButtonScreencastWindow->isChecked() ) {
+        qDebug();
         qDebug().noquote() << global::nameOutput << "Start portal window";
         sourceType = 2;
     }
 
-    if ( ui->radioButtonScreencastArea->isChecked() )
-    {
+    if ( ui->radioButtonScreencastArea->isChecked() ) {
+        qDebug();
         qDebug().noquote() << global::nameOutput << "Start portal area";
         sourceType = 1;
     }
@@ -223,14 +255,12 @@ void QvkMainWindow_wl::slot_start()
     // Value 1 = hidden cursor
     // Value 2 = record cursor
     int mousecursorONOff = 1;
-    if ( ui->checkBoxMouseCursorOnOff->isChecked() == true )
-    {
+    if ( ui->checkBoxMouseCursorOnOff->isChecked() == true ) {
         qDebug().noquote() << global::nameOutput << "Mouse cursor is not recording";
         mousecursorONOff = 1;
     }
 
-    if ( ui->checkBoxMouseCursorOnOff->isChecked() == false )
-    {
+    if ( ui->checkBoxMouseCursorOnOff->isChecked() == false ) {
         qDebug().noquote() << global::nameOutput << "Mouse cursor is recording";
         mousecursorONOff = 2;
     }
@@ -249,10 +279,10 @@ QString QvkMainWindow_wl::get_Area_Videocrop()
     int screenWidth = Screen->size().width();
     int screenHeight = Screen->size().height();
 
-    QString top = QString::number( vkRegionChoise_wl->getYRecordArea() );
-    QString right = QString::number( screenWidth - ( vkRegionChoise_wl->getXRecordArea() + vkRegionChoise_wl->getWidth() ) );
-    QString bottom = QString::number( screenHeight - ( vkRegionChoise_wl->getYRecordArea() + vkRegionChoise_wl->getHeight() ) );
-    QString left = QString::number( vkRegionChoise_wl->getXRecordArea() );
+    QString top = QString::number( vkRegionChoise_wl->get_YRecordArea() );
+    QString right = QString::number( screenWidth - ( vkRegionChoise_wl->get_XRecordArea() + vkRegionChoise_wl->get_Width() ) );
+    QString bottom = QString::number( screenHeight - ( vkRegionChoise_wl->get_YRecordArea() + vkRegionChoise_wl->get_Height() ) );
+    QString left = QString::number( vkRegionChoise_wl->get_XRecordArea() );
     videocrop = "videocrop top=" + top + " " + "right=" + right + " " + "bottom=" + bottom + " " + "left=" + left;
 
     qDebug().noquote() << global::nameOutput << "Area crop from the screen"
@@ -317,6 +347,9 @@ void QvkMainWindow_wl::slot_portal_cancel( uint value )
     Q_UNUSED(value)
     ui->pushButtonStart->setEnabled( true );
     ui->pushButtonStop->setEnabled( false );
+    ui->radioButtonScreencastFullscreen->setEnabled( true );
+    ui->radioButtonScreencastWindow->setEnabled( true );
+    ui->radioButtonScreencastArea->setEnabled( true );
 }
 
 
@@ -374,19 +407,14 @@ void QvkMainWindow_wl::set_check_all_Elements_available()
 
     qDebug().noquote() << global::nameOutput << "--- GStreamer elements ---";
 
-    for ( int i = 0; i < list.count(); i++ )
-    {
+    for ( int i = 0; i < list.count(); i++ ) {
         GstElementFactory *factory = gst_element_factory_find( QString( list.at(i) ).toLatin1() );
-        if ( !factory )
-        {
+        if ( !factory ) {
             qDebug().noquote() << global::nameOutput << "-" << list.at(i);
-            if ( list.at(i) == "pipewiresrc" )
-            {
+            if ( list.at(i) == "pipewiresrc" ) {
                messageBox( "gstreamer-plugin-pipewire" );
             }
-        }
-        else
-        {
+        } else {
             qDebug().noquote() << global::nameOutput << "+" << list.at(i);
             gst_object_unref( factory );
         }
