@@ -3,13 +3,14 @@
 
 #include "ui_formMainWindow_wl.h"
 #include "portal_wl.h"
-
-#include "QvkSpezialSlider.h"
-#include "QvkContainerController.h"
-#include "QvkLogController.h"
+#include "QvkContainerController_wl.h"
 #include "QvkRegionChoise_wl.h"
 
+#include "QvkSpezialSlider.h"
+#include "QvkLogController.h"
+
 #include <QMainWindow>
+#include <QTranslator>
 
 #include <gst/gst.h>
 
@@ -30,13 +31,14 @@ public:
 
 
 private:
-    QvkRegionChoise_wl *vkRegionChoise_wl;
+    QTranslator translator;
+    QTranslator qtTranslator;
 
+    QvkRegionChoise_wl *vkRegionChoise_wl;
     QvkLogController *vklogController;
     GstElement *pipeline = nullptr;
     QStringList videoFormatsList;
     QvkSpezialSlider *sliderFrames;
-//    QWidget *testWidget;
 
     void set_LogController();
     void set_WindowTitle();
@@ -45,7 +47,7 @@ private:
     void set_SpezialSliders();
     void set_Connects();
     void set_check_all_Elements_available();
-    QvkContainerController *vkContainerController;
+    QvkContainerController_wl *vkContainerController_wl;
     void set_RegionChoice();
     void set_test_available_geometry();
 
