@@ -89,8 +89,7 @@ void Portal_wl::requestScreenSharing( int value, int mouseOnOff )
         if ( reply.isError() ) {
             qWarning() << "Couldn't get reply";
             qWarning() << "Error: " << reply.error().message();
-        } else
-        {
+        } else {
             qDebug().noquote() << global::nameOutput << "Begin create portal session";
 
             bool bo = QDBusConnection::sessionBus().connect( QString(),
@@ -107,10 +106,9 @@ void Portal_wl::requestScreenSharing( int value, int mouseOnOff )
 
 void Portal_wl::slot_gotCreateSessionResponse( uint response, const QVariantMap &results )
 {
-    qDebug().noquote() << global::nameOutput << "Got response from portal CreateSession";
+    qDebug().noquote() << global::nameOutput << "slot_gotCreateSessionResponse --Begin--";
 
-    if ( response != 0 )
-    {
+    if ( response != 0 ) {
         qWarning() << "Failed to create session: " << response;
         return;
     }
@@ -127,23 +125,32 @@ void Portal_wl::slot_gotCreateSessionResponse( uint response, const QVariantMap
                              { QLatin1String("types"), (uint)Selection_Screen_Window_Area },
                              { QLatin1String("cursor_mode"), (uint)record_mouse_onOff },
                              { QLatin1String("handle_token"), getRequestToken() } };
+    qDebug().noquote() << global::nameOutput << "slot_gotCreateSessionResponse()" << message;
 
     QDBusPendingCall pendingCall = QDBusConnection::sessionBus().asyncCall(message);
+    qDebug().noquote() << global::nameOutput << "slot_gotCreateSessionResponse()" << pendingCall.error();
+
     QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(pendingCall);
-    connect(watcher, &QDBusPendingCallWatcher::finished, this, [=] (QDBusPendingCallWatcher *watcher) {
+    qDebug().noquote() << global::nameOutput << "slot_gotCreateSessionResponse()" << watcher->error();
+
+    bool bo = connect(watcher, &QDBusPendingCallWatcher::finished, this, [=] (QDBusPendingCallWatcher *watcher) {
         QDBusPendingReply<QDBusObjectPath> reply = *watcher;
         if (reply.isError()) {
-            qWarning() << "Couldn't get reply";
-            qWarning() << "Error: " << reply.error().message();
+            qDebug() << "Couldn't get reply";
+            qDebug() << "Error: " << reply.error().message();
         } else {
-            QDBusConnection::sessionBus().connect(QString(),
+            qDebug().noquote() << global::nameOutput << "slot_gotCreateSessionResponse() into else" << "reply.value().path() :" << reply.value().path();
+            bool bo = QDBusConnection::sessionBus().connect(QString(),
                                                 reply.value().path(),
                                                 QLatin1String("org.freedesktop.portal.Request"),
                                                 QLatin1String("Response"),
                                                 this,
                                                 SLOT( slot_gotSelectSourcesResponse(uint,QVariantMap)));
+            qDebug() << "test test" << bo; // Hahaha, ist true und geht nicht
         }
     });
+
+    qDebug() << "test-1 test-1" << bo;
 }
 
 
